function computeInfoForces(opts)
% function computeInfoForces evaluates information between expected and generate forces
% opt: structure specifying the file to be analized and parameters used in the experiment

% -------------------------
% load sampling parameters
% -------------------------
rec_opts = rec_opts_REPOSITORY(opts.rec);
BIN = rec_opts.bin;
WINDOW = rec_opts.window;
OFFSET = rec_opts.offset;

% -------------------------
% load information analysis parameters
% -------------------------
info_opts = MIForce_opts_REPOSITORY(opts.MIForce);
MIForceResp=info_opts.MIForceResp;
nbin=info_opts.nbin;
nShuffle=info_opts.btsp;

% -------------------------
% load calibration file
% -------------------------
[dirName, fileName] = file_opts_REPOSITORY(opts, 'cal');
load(fullfile(dirName, fileName));
ntrials=cal.testntrials;
info_opts.nt = ntrials;

optsmi.method=info_opts.method;
optsmi.bias=info_opts.bias;
optsmi.btsp=info_opts.btsp;
optsmi.nt=info_opts.nt;


I = NaN(length(cal.units),length(WINDOW),length(OFFSET),length(BIN));                 % create information matrix
Ibtsp = NaN(length(cal.units),length(WINDOW),length(OFFSET),length(BIN),nShuffle);    % create bootstrap values matrix

for uu=1:length(cal.units),
    
    for ii = 1:numel(BIN) % bin size
        
        for jj = 1:numel(WINDOW)    % window size
            
            for kk = 1:numel(OFFSET);   % offset
                
                % get the forces for each trial/stimulus
                Forces = shiftdim(squeeze(cal.ForceTest(uu,jj,kk,ii,:,:,:)),2);
                [Flength ,maxTrial,nStim]=size(Forces);
                
                try
                    switch MIForceResp
                        
                        case 'FxFy'
                            R = Forces;
                            
                            fx=squeeze(Forces(1,:,:));
                            fy=squeeze(Forces(2,:,:));
                            nfx=length(unique(fx(~isnan(fx(:)))));
                            nfy=length(unique(fy(~isnan(fy(:)))));
                            R = binr(R, ntrials, min([nfx; nfy; nbin]), 'eqspace');
                            
%                             R = binr(R, ntrials, nbin, 'eqpop');
                            
                        case 'RT'
                            F = abs(Forces(1,:,:) + Forces(2,:,:)*1i);
                            T = angle(Forces(1,:,:) + Forces(2,:,:)*1i);
                            nF=length(unique(F(~isnan(F(:)))));
                            nT=length(unique(T(~isnan(T(:)))));
                            R = zeros(2,maxTrial,nStim);
                            R(1,:,:) = binr(F, ntrials, min([nF; nbin]), 'eqpop');
                            R(2,:,:) = binr(T, ntrials, min([nT; nbin]), 'eqspace');
                            
%                             R = zeros(2,maxTrial,nStim);
%                             R(1,:,:) = abs(Forces(1,:,:) + Forces(2,:,:)*1i);
%                             R(2,:,:) = angle(Forces(1,:,:) + Forces(2,:,:)*1i);
%                             R = binr(R, ntrials, nbin, 'eqpop');
                            
                        case 'AC' % response is angle code
                            % WARNING: only works if each stim produces a
                            % recForce with a different angle!
                            R = zeros(1,maxTrial,nStim);
                            recForce = squeeze(cal.RecForce(uu,jj,kk,ii,:,:));
                            absCal = abs(recForce(:,1)+recForce(:,2)*1i);
                            absForce= squeeze(abs(Forces(1,:,:) + Forces(2,:,:)*1i));
                            
                            for ll = 1:nStim
                                diffAngle = acos((recForce*squeeze(Forces(:,1:ntrials(ll),ll)))./(absCal*absForce(1:ntrials(ll),ll)'));
                                [closeststim tmp]=find(diffAngle==repmat(min(diffAngle,[],1),[nStim 1]));
                                R(:,1:ntrials(ll),ll) = closeststim;
                            end
                            
%                             % make a confusion matrix
%                             cm=nan(nStim);
%                             for ss1=1:nStim
%                                 dec=squeeze(R(:,1:ntrials(ss1),ss1));
%                                 for ss2=1:nStim
%                                     cm(ss1,ss2)=100*sum(dec==ss2)/ntrials(ss1);
%                                 end;
%                             end;
                            
                        otherwise
                            error('case not set.');
                    end;
                    
                    tmpI = information(double(R), optsmi, 'Ish');
                    I(uu,jj,kk,ii) = tmpI(1);
                    Ibtsp(uu,jj,kk,ii,:) = tmpI(2:end);
                catch
                    sprintf('Info could not be computed for %s, with the parameters: bin=%d, win=%d, offset=%d, Resp=%s',opts.set,BIN(ii),WINDOW(jj),OFFSET(kk),MIForceResp)
                end
            end
        end
    end
end;

[dirName, fileName] = file_opts_REPOSITORY(opts, 'infoForce');
save(fullfile(dirName, fileName),'I','Ibtsp');  % save information and bootstrap matrices
