function computeInfoForcesFromTraj(opts)
% function computeInfoForces evaluates information between expected and generate forces
% opt: structure specifying the file to be analized and parameters used in the experiment

% -------------------------
% load sampling parameters
% -------------------------
rec_opts = rec_opts_REPOSITORY(opts.rec);
BIN = rec_opts.bin;
WINDOW = rec_opts.window;
OFFSET = rec_opts.offset;

% -------------------------
% load information analysis parameters
% -------------------------
info_opts = MIForce_opts_REPOSITORY(opts.MIForce);
MIForceResp=info_opts.MIForceResp;
nbin=info_opts.nbin;
nShuffle=info_opts.btsp;

% -------------------------
% load calibration file
% -------------------------
[dirName, fileName] = file_opts_REPOSITORY(opts, 'cal');
load(fullfile(dirName, fileName));

% -------------------------
% load simulation file
% -------------------------
[dirName, fileName] = file_opts_REPOSITORY(opts, 'sim');
load(fullfile(dirName, fileName));
F=sim.Force;
stim=sim.Stimulation;
nStim=max(unique(stim(:)));

optsmi.method=info_opts.method;
optsmi.bias=info_opts.bias;
optsmi.btsp=info_opts.btsp;

[nunitset, nwin, noff, nbins, nrun, nstp, nfdim]=size(F);
I = NaN(nunitset, nwin, noff, nbins);                 % create information matrix
Ibtsp = NaN(nunitset, nwin, noff, nbins,nShuffle);    % create bootstrap values matrix

for uu=1:nunitset,
    
    for ii = 1:nbins % bin size
        
        for jj = 1:nwin    % window size
            
            for kk = 1:noff;   % offset
                
                Ftmp=squeeze(F(uu,jj,kk,ii,:,:,:));
                stimtmp=squeeze(stim(uu,jj,kk,ii,:,:));
                
                try
                    
                    for ss=1:nStim;
                        [runid{ss} stpid{ss}]=find(stimtmp==ss);
                        ntrials(ss)=length(runid{ss});
                    end;
                    maxTrial=max(ntrials);
                    notemptystims=find(ntrials>10);
                    ntrials=ntrials(notemptystims);
                    optsmi.nt = ntrials;
                    
                    Forces=nan(2,maxTrial,length(notemptystims));
                    for ss=1:length(notemptystims);
                        for tr=1:ntrials(notemptystims(ss))
                            Forces(:,tr,ss)=Ftmp(runid{notemptystims(ss)}(tr),stpid{notemptystims(ss)}(tr),:);
                        end;
                    end;
                    
                    switch MIForceResp
                        
                        case 'FxFy'
                            R = Forces;
                            
                            fx=squeeze(Forces(1,:,:));
                            fy=squeeze(Forces(2,:,:));
                            nfx=length(unique(fx(~isnan(fx(:)))));
                            nfy=length(unique(fy(~isnan(fy(:)))));

                            R = binr(R, ntrials, min([nfx; nfy; nbin]), 'eqspace');
                            
                        case 'RT'
                            F = abs(Forces(1,:,:) + Forces(2,:,:)*1i);
                            T = angle(Forces(1,:,:) + Forces(2,:,:)*1i);
                            nF=length(unique(F(~isnan(F(:)))));
                            nT=length(unique(T(~isnan(T(:)))));
                            
                            R = zeros(2,maxTrial,nStim);
                            R(1,:,:) = binr(F, ntrials, min([nF; nbin]), 'eqpop');
                            R(2,:,:) = binr(T, ntrials, min([nT; nbin]), 'eqspace');
                                                        
                        case 'AC' % response is angle code
                            R = zeros(1,maxTrial,nStim);
                            recForce = squeeze(cal.RecForce(uu,jj,kk,ii,:,:));
                            absCal = abs(recForce(:,1)+recForce(:,2)*1i);
                            absForce= squeeze(abs(Forces(1,:,:) + Forces(2,:,:)*1i));
                            
                            for ll = 1:nStim
                                diffAngle = acos((recForce*squeeze(Forces(:,1:ntrials(ll),ll)))./(absCal*absForce(1:ntrials(ll),ll)'));
                                [closeststim tmp]=find(diffAngle==repmat(min(diffAngle,[],1),[nStim 1]));
                                R(:,1:ntrials(ll),ll) = closeststim;
                            end
                            
                        otherwise
                            error('case not set.');
                    end;
                    
                    tmpI = information(double(R), optsmi, 'Ish');
                    I(uu,jj,kk,ii) = tmpI(1);
                    Ibtsp(uu,jj,kk,ii,:) = tmpI(2:end);
                catch
                    sprintf('Info could not be computed for %s, with the parameters: bin=%d, win=%d, offset=%d, Resp=%s',opts.set,BIN(ii),WINDOW(jj),OFFSET(kk),MIForceResp)
                end
            end
        end
    end
end;

[dirName, fileName] = file_opts_REPOSITORY(opts, 'infoForceFromTraj');
save(fullfile(dirName, fileName),'I','Ibtsp');  % save information and bootstrap matrices
