function computeMIStimSU(opts)
% function computeInfoBinningParams evaluates information between spike count and stimulation
%
% opts: structure containing sampling parameters and other parameters
%
% Marianna Semprini & Fran�ois Szymanski
% IIT, May 2010

% -------------------------
% load .mat file
% -------------------------
[dirName, fileName] = file_opts_REPOSITORY(opts, 'raw mat');
load(fullfile(dirName, fileName));  % load data and dataParams;

% -------------------------
% load sampling parameters
% -------------------------
rec_opts = rec_opts_REPOSITORY(opts.rec);
BIN = rec_opts.bin;
WINDOW = rec_opts.window;
OFFSET = rec_opts.offset;

% -------------------------
% load information analysis parameters
% -------------------------
info_opts = info_opts_REPOSITORY(opts.info);
info_opts.nt = dataParams.trialN;
nShuffle=info_opts.btsp;


[nT, maxTrial, nUnit, nStim] = size(data);

I = NaN(nUnit,length(WINDOW),length(OFFSET),length(BIN));
Ibtsp = NaN(nUnit,length(WINDOW),length(OFFSET),length(BIN),nShuffle);

for ii = 1:numel(BIN) % choose bin size
    bin = BIN(ii);

    for jj = 1:numel(WINDOW)    % choose window size
        window = WINDOW(jj);

        for kk = 1:numel(OFFSET);   % choose offset
            offset = OFFSET(kk);

            tmpData = createDataSet(data, [offset offset+window bin]);
           
            tmpI = unitInformation(tmpData, info_opts); % calculate unit information and bootstrap values
            
            I(:,jj,kk,ii) = tmpI(:,1);              % first columns are information...
            Ibtsp(:,jj,kk,ii,:) = tmpI(:,2:end);    % ... the others are bootstrap values

        end
    end
end

[dirName, fileName] = file_opts_REPOSITORY(opts, 'MI stim SU');
save(fullfile(dirName, fileName), 'I', 'Ibtsp');