function I = unitInformation(data, opts)
% function unitInfo calculate unit information 
% 
% data: (time X maxTrials X nUnits X nStimuli) matrix containing spike count
% opts : Information analysis options
%
% I: [nCell X nnShufflep] matrix of information values

% Marianna Semprini & Fran�ois Szymanski
% IIT, April 2010

[nT, maxTrial, nUnit, nStim] = size(data);

I = zeros(nUnit, 1+opts.btsp);
for ii = 1:nUnit
    tmpData = zeros(sum(opts.nt), nT);
    index = 0;
    for jj = 1:nStim    % collect unit ii data in one matrix
        stimTrial = opts.nt(jj);
        tmpData(1+index:index+stimTrial,:) = squeeze(data(:,1:stimTrial,ii,jj))';           
        index = index + stimTrial;
    end
    
    [c, s] = princomp(tmpData); % run PCA
    p1 = s(:,1); % scores of first component
    p2 = s(:,2); % scores of second component
    
    R = zeros(2,maxTrial,nStim); 
    index = 0;
    for jj = 1:nStim
        stimTrial = opts.nt(jj);
        R(1,1:stimTrial,jj) = p1(1+index:index+stimTrial);
        R(2,1:stimTrial,jj) = p2(1+index:index+stimTrial);
        index = index + stimTrial;
    end 
    try
        R = binr(R, opts.nt, opts.nbin, 'eqpop');
        I(ii,:) = information(R, opts, 'Ish');
    catch
        I(ii,:) = NaN; % no spikes
    end
end