function calmat= calib_algo2_dist(data, opts)

% -------------------------
% load dynamical system parameters
% -------------------------
dynSys_opts = dynSys_opts_REPOSITORY(opts.dynSys);
Xrange = dynSys_opts.Xrange;
Yrange = dynSys_opts.Yrange;
% -------------------------

% -------------------------
% load algo2 parameters
% -------------------------
algo2_opts = algo2_opts_REPOSITORY(opts.algo);
% -------------------------

% get data dimensions
[nT, nTrial, nUnit, nStim] = size(data);

% Multineuron Spike Train Metric described in (Houghton & Sen, 2008)
distopts.set=opts.set;
distopts.dist=opts.dist;
distopts.saveitonhdd=1;
distopts.trialN=nTrial*ones(1,nStim);
[D distmat]=compDist(data,distopts);

% remove what corresponds to the "bad" stimuli from D, Acal and e
if size(distmat.Acal,2)>(nStim*nTrial)
    stim2keep=opts.stim2keep;
%     distmat.e=distmat.e(opts.stim2keep,opts.stim2keep);
    Dold=D;
    Acalold=distmat.Acal;
    D=nan(nStim*nTrial);
    Acal=nan(size(Acalold,1),nStim*nTrial,nUnit);
    for ss1=1:nStim,
        Acal(:,(ss1-1)*nTrial+(1:nTrial),:)=Acalold(:,(stim2keep(ss1)-1)*nTrial+(1:nTrial),:);
        for ss2=1:nStim,
            D((ss1-1)*nTrial+(1:nTrial),(ss2-1)*nTrial+(1:nTrial))=Dold((stim2keep(ss1)-1)*nTrial+(1:nTrial),(stim2keep(ss2)-1)*nTrial+(1:nTrial));
        end;
    end;
    distmat.Acal=Acal;
end;

Davg=nan(nStim,nStim);
for ss1=1:nStim,
    for ss2=1:nStim,
        dtmp=D((ss1-1)*nTrial+(1:nTrial),(ss2-1)*nTrial+(1:nTrial));
        Davg(ss1,ss2)=mean(dtmp(:));
    end;
end;

% MDS to obtain a 2D position for each calibration trial
[Y,stress,disparities] = mdscale(D,2,'criterion',algo2_opts.MDScrit);


scalF=nan(1,2);
offset=zeros(1,2);
% rescale positions to match the sensory field size
if isstr(algo2_opts.scalfact) && strcmp(algo2_opts.scalfact,'ScaleYtoField')
    % positions scaled to sensory field
    
    scalF(1)=((max(Xrange)-min(Xrange))/(max(Y(:,1))-min(Y(:,1))));
    scalF(2)=((max(Yrange)-min(Xrange))/(max(Y(:,2))-min(Y(:,2))));
    Ys=Y.*repmat(scalF,size(Y,1),1);
    offset(1)=(max(Xrange)-max(Ys(:,1)));
    offset(2)=(max(Yrange)-max(Ys(:,2)));
    Ys=Ys+repmat(offset,size(Y,1),1);
    Y2=reshape(Ys,[nTrial nStim 2]);
    RecPoinT=squeeze(mean(Y2,1))';
    
elseif isstr(algo2_opts.scalfact) && strcmp(algo2_opts.scalfact,'ScaleYtoFieldNoShift')
    % positions scaled to sensory field
    
    scalF(1)=((max(Xrange)-min(Xrange))/(max(Y(:,1))-min(Y(:,1))));
    scalF(2)=((max(Yrange)-min(Yrange))/(max(Y(:,2))-min(Y(:,2))));
    Ys=Y.*repmat(scalF,size(Y,1),1);
%     offset(1)=(max(Xrange)-max(Ys(:,1)));
%     offset(2)=(max(Yrange)-max(Ys(:,2)));
%     Ys=Ys+repmat(offset,size(Y,1),1);
    Y2=reshape(Ys,[nTrial nStim 2]);
    RecPoinT=squeeze(mean(Y2,1))';
        
elseif isnumeric(algo2_opts.scalfact)
    Y2=reshape(Y,[nTrial nStim 2]);
    RecPoinT=squeeze(mean(Y2,1))';
    scalF=[1 1]*((algo2_opts.scalfact)*Xrange(2))/max(abs(RecPoinT(:)));
    RecPoinT=RecPoinT'.*repmat(scalF,nStim,1);
    RecPoinT=RecPoinT';
    
else
    error('algo2_opts.scalfact is not well defined');
end;


    
% RecPoinT=(RecPoinT./repmat(max(abs(RecPoinT(:))),2,nStim)).*((algo2_opts.scalfact)*repmat([Xrange(2); Yrange(2)],1,nStim));

% translate points such that the target is located at the interesection
% between 3 regions
CenterPoint=[0 0];
if algo2_opts.intersectShift
    [KPts KTrips]=GetIntersecPts(RecPoinT');
    [x, idx]=min(sum(KPts.^2,2));
    CenterPoint=KPts(idx,:);
    RecPoinT=RecPoinT-repmat(CenterPoint',[1 nStim]);
end;


% find sensory regions by nearest neighbour method

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% in this case I removed the dsearch that it is not anymore supported%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% TRI = delaunay(RecPoinT(1,:),RecPoinT(2,:));
TRI = DelaunayTri(RecPoinT(1,:)',RecPoinT(2,:)');

ax=Xrange(1):.1:Xrange(2);
sensfield=nan(length(ax));
for x = 1:length(ax)
    for y = 1:length(ax)
%         nearest = dsearch(RecPoinT(1,:),RecPoinT(2,:),TRI,ax(x),ax(y));
        nearest = nearestNeighbor(TRI,ax(x),ax(y));
        sensfield(y,x)=nearest;
    end
end

if ~algo2_opts.ForceFromRegionCenter
    % take the ideal force at the RecPoinT
    RecPoinT2=RecPoinT; 
else
    % take the ideal force at the center of each region
    % take the center of each region
    RecPoinT2=nan(size(RecPoinT));
    for ss=1:nStim,
        [I J]=find(sensfield==ss);
        RecPoinT2(:,ss)=[ax(round(mean(J))) ax(round(mean(I)))];
    end; 
end;

RecForce=nan(size(RecPoinT2));
for ss=1:nStim
    RecForce(:,ss)=dynSys_opts.FF(RecPoinT2(:,ss));
end;
% if isfield(dynSys_opts,'stiffness')
%     Stiffness = dynSys_opts.stiffness;
%     RecForce=-Stiffness*RecPoinT2;
% elseif isfield(dynSys_opts,'FFGauss')
%     sigma=dynSys_opts.FFGauss.sigma;
%     sf=dynSys_opts.FFGauss.sf;
%     Fg=dynSys_opts.FFGauss.Fg;
%     RecForce=nan(size(RecPoinT2));
%     for ss=1:nStim
%         RecForce(:,ss)=Fg(RecPoinT2(:,ss),sigma,sf);
%     end;
% else
%     error('problem in dynSys_opts');
% end;

%____________________
%       SAVE
%____________________
calmat.algo='algo2';
calmat.nStim=nStim;
calmat.nTrial=nTrial;
calmat.nUnit=nUnit;
calmat.K2D=distmat.K2D;
calmat.e=distmat.e;
calmat.Acal=distmat.Acal;
calmat.D=D;
calmat.Davg=Davg;
calmat.RecPoint=RecPoinT;
calmat.RecForce=RecForce;
calmat.Ycal=Y;
calmat.scalF=scalF;
calmat.offset=offset;
calmat.CenterPoint=CenterPoint;
calmat.other.Y2=Y2;
calmat.other.scalF=scalF;
calmat.other.CenterPoint=CenterPoint;
calmat.other.RecPoinT=RecPoinT;
calmat.other.RecPoinT2=RecPoinT2;
calmat.other.ax=ax;
calmat.other.sensfield=sensfield;




