function out=comp_force_algo2_dist(calmat, activity,opts)
% compute the Force corresponding to a given neural activity

% -------------------------
% load algo2 parameters
% -------------------------
algo2_opts = algo2_opts_REPOSITORY(opts.algo);
% -------------------------

RecForce=calmat.RecForce;

if isfield(calmat,'Dtr')
    Dtr=calmat.Dtr;
else
    Dtr=compDistTrial2Calib(calmat, activity);
end;

z=-2;
% replace 0s by a small value. With our low dimensional simulated data,
% it often happens that an identical spike train is elicited by several
% stimuli. In that case there is a 0 distance between the spike train to be
% decoded, and diverse trials corresponding to several stimuli. And because
% 0^-2=infinity, we get an average distance of 0 to these stimuli.
% Replacing 0s by a small value avoid that problem.
D2tr=Dtr;
D2tr(D2tr==0)=min(D2tr(D2tr~=0))/100;

Dtravg=mean(D2tr.^z,2).^(1/z);

% [minstim, decostim]=min(Dtravg);

% we select the stimulus that elicited the closest cluster
[minstim, I]=min(Dtravg);
% check if other mimima exist
minvalidx=find(Dtravg==minstim);
% if more than one minimum
if numel(minvalidx)>1,
    % select decoded stimulus at random amongst them
    I=minvalidx(ceil(rand*numel(minvalidx)));
end;
decostim=I;
        
out.decostim=decostim;

switch algo2_opts.Fcomp
    
    case 'decode stimulus'
        Force=RecForce(:,decostim);
        
    case 'weights from normalized inverse distances'
        p=algo2_opts.p;
        if minstim==0
            Force=RecForce(:,decostim);
        else
            nstims=calmat.nStim; % try on a subset of the closest stimuli?
            [Y I]=sort(Dtravg);
            Force=sum(RecForce(:,I(1:nstims)).*repmat((1./Dtravg(I(1:nstims)).^p)/sum(1./Dtravg(I(1:nstims)).^p),1,2)',2);
        end;
        
    case 'weights from correlation between trial distances and calib distances'
        Dcorr=nan(1,calmat.nStim);
        for ss=1:calmat.nStim,
            Dcorr(ss)=corr(calmat.Davg(ss,:)',Dtravg);
        end;
        W=Dcorr; % find the max to decode better than with min(Dtravg)???
        Force=sum(RecForce.*repmat(W',1,2)',2);
        
    case 'weights from trial distances x inverse calib distances matrix'
        W=(calmat.Davg\Dtravg)';
        Force=sum(RecForce.*repmat(W',1,2)',2);
        
    case 'project trial in 2D using MDS'
        D=zeros(calmat.nStim*calmat.nTrial+1);
        D(1:calmat.nStim*calmat.nTrial,1:calmat.nStim*calmat.nTrial)=calmat.D;
        Dtrtmp=Dtr';
        D(end,1:end-1)=Dtrtmp(:);
        D(1:end-1,end)=Dtrtmp(:);
        
        if strcmp(algo2_opts.MDScrit,'sammon')
            [I J]=find(D==0);
            z=find(I~=J); I=I(z); J=J(z);
            D(sub2ind(size(D),I,J))=0.1*min(D(D>0));
        end;
        
        Y=calmat.Ycal;
        Y(end+1,:)=[0 0];
        Y = mdscale(D,2,'Start',Y,'criterion',algo2_opts.MDScrit);
        decpos=calmat.scalF.*Y(end,:)+calmat.offset-calmat.CenterPoint;
        dynSys_opts = dynSys_opts_REPOSITORY(opts.dynSys);
        
        Force=dynSys_opts.FF(decpos');
%         if isfield(dynSys_opts,'stiffness')
%             Stiffness = dynSys_opts.stiffness;
%             Force=-Stiffness*decpos';
%         elseif isfield(dynSys_opts,'FFGauss')
%             sigma=dynSys_opts.FFGauss.sigma;
%             sf=dynSys_opts.FFGauss.sf;
%             Fg=dynSys_opts.FFGauss.Fg;
%             Force=Fg(decpos',sigma,sf);
%         else
%             error('problem in dynSys_opts');
%         end;
        
        out.decpos=decpos;
        
    case 'force at position of most similar calibration trial'
        Y=calmat.Ycal;
        %  organise distances in the same order as Y
        D2trl=D2tr';
        D2trl=D2trl(:);
        
        % find most similar calibration spike train 
        [mintr, I]=min(D2trl);
        % check if other mimima exist
        minidx=find(D2trl==mintr);
        % if more than one minimum
        if numel(minidx)>1,
            % select decoded trial at random amongst them
            I=minidx(ceil(rand*numel(minidx)));
        end;

        % and take its position
        decpos=Y(I,:);
        decpos=calmat.scalF.*decpos+calmat.offset-calmat.CenterPoint;
        
        dynSys_opts = dynSys_opts_REPOSITORY(opts.dynSys);
        
        Force=dynSys_opts.FF(decpos');
%         if isfield(dynSys_opts,'stiffness')
%             Stiffness = dynSys_opts.stiffness;
%             Force=-Stiffness*decpos';
%         elseif isfield(dynSys_opts,'FFGauss')
%             sigma=dynSys_opts.FFGauss.sigma;
%             sf=dynSys_opts.FFGauss.sf;
%             Fg=dynSys_opts.FFGauss.Fg;
%             Force=Fg(decpos',sigma,sf);
%         else
%             error('problem in dynSys_opts');
%         end;
        
        out.decpos=decpos;
                
    otherwise
        error('algo inexistent');
        
end;

out.Force=Force;






