function calibrate_loop(opts)
% function simulateDynamicShaping run simulations of Dynamic Shaping
%
% opts: structure containing parameters of sampling, Dynamic Shaping and others
%
% Marianna Semprini & Fran�ois Szymanski
% IIT, May 2010

% -------------------------
% load .mat file
% -------------------------
[dirName, fileName] = file_opts_REPOSITORY(opts, 'raw mat');
load(fullfile(dirName, fileName));  % load data and dataParams;
% rawData = data_online; dataParams.trialN=[200 200 200 200];
rawData = data;
clear data;
% remove data with too little trials
badstim=dataParams.trialN<20;
if isfield(dataParams,'stimPatterns') && ~isempty(dataParams.stimPatterns), dataParams.stimPatterns(badstim,:)=[]; end;
dataParams.trialN(badstim)=[];
rawData(:,:,:,badstim)=[];
[nT, maxTrial, nUnit, nStim] = size(rawData);

%  dataParams.trialN=fliplr(dataParams.trialN);
%  rawData=flipdim(rawData,4);
% -------------------------

% -------------------------
% load sampling parameters
% -------------------------
rec_opts = rec_opts_REPOSITORY(opts.rec);
WINDOW = rec_opts.window;
OFFSET = rec_opts.offset;
switch opts.algo(1:5)
    case 'algo1'
        BIN = rec_opts.bin;
    case 'algo2'
        % rather than binning the spike matrix, we convolve it with a
        % kernel of time constant tc during the computation of the
        % distances
        %         opts.tc=rec_opts.bin;
        BIN=1;
        WINDOW=nT;
        OFFSET=0;
end;

% -------------------------

% -------------------------
% load calibration parameters
% -------------------------
cal_opts = cal_opts_REPOSITORY(opts.cal);
unitset = cal_opts.unitset;
datorder = cal_opts.datorder;
nCal = cal_opts.nCalibrations;
decthresh=cal_opts.decthresh;
minNStim=cal_opts.minNStim;
% -------------------------

minTrial = min(dataParams.trialN);


%% -------------------------
% Remove "bad" stimuli based on the parameters decthresh & minNStim
% (or NBestStim) found in cal_opts
% -------------------------
% -------------------------
% load parameters for computing distances
% -------------------------
distopts.set=opts.set;
distopts.dist=opts.dist;
distopts.saveitonhdd=1;
distopts.trialN=dataParams.trialN*0+nCal;
dataCal = rawData(:,1:nCal,:,:);
%~~~~~~~~~~~~~~~~~  WARNING : SAVING on HardDrive  ~~~~~~~~~~~~~~~~~~~~~~~~
D=compDist(dataCal,distopts);
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
decstim=decoDist(D,distopts);
nTrial=distopts.trialN(1);
deccorrect=decstim==repmat(1:nStim,[nTrial 1]);
deccorrectperc=100*mean(deccorrect,1);

if ~isfield(cal_opts,'NBestStim')
    stim2keep=find(deccorrectperc>=decthresh);
    while length(stim2keep)<minNStim
        decthresh=decthresh-5;
        stim2keep=find(deccorrectperc>=decthresh);
    end;
else
    [~, stimrank]=sort(deccorrectperc,'descend');
    stim2keep=stimrank(1:cal_opts.NBestStim);
end;

opts.stim2keep=stim2keep;
rawData=rawData(:,:,:,stim2keep);
[nT, maxTrial, nUnit, nStim] = size(rawData);


%%
switch unitset
    case 'allunits'
        % use all units
        units{1}=1:nUnit;
        
        % WARNING: NOT UPTODATE
    case 'signifunits'
        % load info file
        [dirName, fileName] = file_opts_REPOSITORY(opts, 'MI stim SU');
        load(fullfile(dirName, fileName));  % load I and Ibtsp
        
        % select units whose value is significant in at least one dataset
        I = reshape(I,size(I,1),size(I,2)*size(I,3)*size(I,4));
        Ibtsp = reshape(Ibtsp,size(I,1),size(I,2)*size(I,3)*size(I,4),size(Ibtsp,5));
        unit = zeros(size(I));
        for ii = 1:size(I,1)
            for jj = 1:size(I,2)
                tmpI = I(ii,jj);
                tmpIbtsp = squeeze(Ibtsp(ii,jj,:));
                edges = [0:0.005:0.1];
                distr = histc(tmpIbtsp,edges);
                index = find(distr);
                if ~isempty(index)
                    distrL = (edges(index(end)) - edges(index(1)));
                    th = distrL*95/100;
                    if tmpI>th
                        unit(ii,jj) = 1;
                    end
                end
            end
        end
        units{1} = find(sum(unit,2));
        
        % WARNING: NOT UPTODATE
    case 'sortunits'
        % load info file
        [dirName, fileName] = file_opts_REPOSITORY(opts, 'MI stim SU');
        load(fullfile(dirName, fileName));  % load I and Ibtsp
        
        % sort units according to their information value
        info = I - nanmean(Ibtsp,5);
        info = reshape(info, size(info,1), size(info,2)*size(info,3)*size(info,4));
        [sortI, unitstmp] = sort(mean(info,2));
        
        for uu = 1:nUnit-1
            units{uu} = unitstmp(uu:end);
        end;
        
    otherwise
        error('This option to define the subset of units doesnt exist.');
end;

switch datorder
    case 'normal'
        nbforcetest=maxTrial-nCal;
    case 'shuffle'
        nbforcetest=minTrial-nCal;
end;

cal.RecPoint = zeros(length(units),numel(WINDOW),numel(OFFSET), numel(BIN),nStim,2,'single');
cal.RecForce = zeros(length(units),numel(WINDOW),numel(OFFSET), numel(BIN),nStim,2,'single');
cal.ForceCal = zeros(length(units),numel(WINDOW),numel(OFFSET), numel(BIN),nCal,nStim,2,'single');
cal.ForceTest = zeros(length(units),numel(WINDOW),numel(OFFSET), numel(BIN),nbforcetest,nStim,2,'single');
cal.units=units;

for uu=1:length(units),
    
    for ii = 1:numel(BIN) % choose bin size
        bin = BIN(ii);
        
        for jj = 1:numel(WINDOW)    % choose window size
            window = WINDOW(jj);
            
            for kk = 1:numel(OFFSET);   % choose offset
                offset = OFFSET(kk);
                
                switch datorder
                    case 'normal'
                        tmpData = createDataSet(rawData(:,:,units{uu},:), [offset offset+window bin]);
%                                                 tmpData = rawData;
                        nT = size(tmpData,1);
                        
                        % create dataset for calibration and simulation
                        dataCal = NaN(nT, nCal, length(units{uu}), nStim);
                        data = NaN(nT, maxTrial - nCal, length(units{uu}), nStim);
                        ntrials = dataParams.trialN(stim2keep) - nCal;
                        
                        for ss = 1:nStim
                            index = [1:1:dataParams.trialN(stim2keep(ss))];
                            dataCal(:,:,:,ss) = tmpData(:,index(1:nCal),:,ss);
                            data(:,1:ntrials(ss),:,ss) = tmpData(:,index(nCal+1:end),:,ss);
                        end
                        
                    case 'shuffle'
                        data = createDataSet(rawData(:,1:minTrial,units{uu},:), [offset offset+window bin]);  % create dataset
%                                                 data = rawData(:,1:minTrial,units{uu},:);
                        nT = size(data,1);
                        index = randperm(numel(data));
                        data = reshape(data(index),size(data));
                        
                        % create dataset for calibration and simulation
                        dataCal = data(:,1:nCal,:,:);
                        data = data(:,nCal+1:end,:,:);
                        ntrials = (minTrial-nCal)*ones(1, nStim);
                        
                    otherwise
                        error('The choice of Simulation type is invalid.')
                end;
                
                out = runCalibration(data, dataCal, ntrials, opts);
                
                % store results
                nStim=out.nStim;
                cal.RecPoint(uu,jj,kk,ii,1:nStim,:) = out.RecPoint';
                cal.RecForce(uu,jj,kk,ii,1:nStim,:) = out.RecForce';
                cal.ForceCal(uu,jj,kk,ii,:,1:nStim,:)=out.ForceCal;
                cal.ForceTest(uu,jj,kk,ii,:,1:nStim,:)=out.ForceTest;
                if strcmp(opts.algo(1:5),'algo2')
                    cal.dispfield{uu,jj,kk,ii}=out.other;
                end;
            end
        end
    end
end;

cal.RecPoint=cal.RecPoint(:,:,:,:,1:nStim,:);
cal.RecForce=cal.RecForce(:,:,:,:,1:nStim,:);
cal.ForceCal=cal.ForceCal(:,:,:,:,:,1:nStim,:);
cal.ForceTest=cal.ForceTest(:,:,:,:,:,1:nStim,:);
cal.testntrials=ntrials(1:nStim);

% save results
[dirName, fileName] = file_opts_REPOSITORY(opts, 'cal');
save(fullfile(dirName, fileName), 'cal');
