function [FxR, FyR]= rangeF(K, Dx, Dy)
% function rangeF finds the range of force for an elastic field (K) within a domain Dx, Dy

% K: stiffness
% Dx: vector containing the field extremities along x axe
% Dy: vector containing the field extremities along y axe
%
% FxR: x force range
% FyR: y force range


varx = Dx(2)-Dx(1);
stepx = varx/10;
vary = Dy(2)-Dy(1);
stepy = vary/10;

Fxmax = 0;
Fxmin = 0;
Fymax = 0;
Fymin = 0;
for x = Dx(1):stepx:Dx(2)
    for y = Dy(1):stepy:Dy(2)
        Fx = K(1,:)*[x;y];
        Fy = K(2,:)*[x;y];
        if (Fx > Fxmax)
            Fxmax = Fx;
        end
        if (Fx < Fxmin)
            Fxmin = Fx;
        end
        if (Fy > Fymax)
            Fymax = Fy;
        end
        if (Fy < Fymin)
            Fymin = Fy;
        end
    end
end
FxR = abs(Fxmax-Fxmin);
FyR = abs(Fymax-Fymin);



