function cal = runCalibration(data, dataCal, ntrials, opts)
% runs the calibration corresponding to the desired algo opts.algo
% and derives the forces from the testing set

%% CALIBRATION

% run calibration
calmat = calib_algo(dataCal,opts);
nStim=calmat.nStim; dataCal=dataCal(:,:,:,1:nStim);
cal.nStim=nStim;
cal.RecForce = calmat.RecForce;
cal.RecPoint = calmat.RecPoint;

%% COMPUTE FORCES FROM THE NEURAL ACTIVITY

% get data dimensions
[nT, maxTrial, nUnit, nStim] = size(dataCal);

% compute Forces corresponding to data in calibration set
ForceCal=nan(maxTrial,nStim,2);
% decposCal=nan(maxTrial,nStim,2);
% decstimCal=nan(maxTrial,nStim);
for kk = 1:nStim
    for ii=1:maxTrial
        activity = zeros(nT, nUnit);    % needed in case nT == 1
        activity(:,:) = squeeze(dataCal(:,ii,:,kk));
        if strcmp(opts.algo(1:5),'algo2') % to speed up algo 2
            calmat.Dtr=reshape(calmat.D(:,ii+(kk-1)*maxTrial),[maxTrial nStim])';
        end;
        out=comp_force_algo(calmat, activity,opts);
        ForceCal(ii,kk,:) = out.Force;
%         decposCal(ii,kk,:) = out.decpos;
%         decstimCal(ii,kk) = out.decostim;
    end;
end;

% speeds up algo 2 by loading distances computations if already computed
if strcmp(opts.algo(1:5),'algo2')
    calmat=rmfield(calmat, 'Dtr');
    calmat.nT=nT;
    DtrAllTest=compDtrAllTest(calmat,ntrials,opts,data);
    DtrAllTest=DtrAllTest(opts.stim2keep,:,opts.stim2keep,:);
end;

% compute Forces corresponding to data in test set
ForceTest=nan(max(ntrials),nStim,2);
% decposTest=nan(maxTrial,nStim,2);
% decstimTest=nan(maxTrial,nStim);
for kk = 1:nStim
    for ii=1:ntrials(kk)
        activity = zeros(nT, nUnit);    % needed in case nT == 1
        activity(:,:) = squeeze(data(:,ii,:,kk));
        if strcmp(opts.algo(1:5),'algo2')
            calmat.Dtr=squeeze(DtrAllTest(kk,ii,:,:));
        end;
        out=comp_force_algo(calmat, activity,opts);
        ForceTest(ii,kk,:) = out.Force;
%         decposTest(ii,kk,:) = out.decpos;
%         decstimTest(ii,kk) = out.decostim;
    end;
end;

cal.ForceCal=ForceCal;
cal.ForceTest=ForceTest;

% for plotting purposes
if strcmp(opts.algo(1:5),'algo2')
    cal.other=calmat.other;
end;
