function runSimulation_idealFF(opts)


global ExternalForce Mass Damping % parameters to be shared with mbf

% -------------------------
% load dynamical system parameters
% -------------------------
dynSys_opts = dynSys_opts_REPOSITORY(opts.dynSys);
% stiffness = dynSys_opts.stiffness;
Mass = dynSys_opts.mass;
Damping = dynSys_opts.damping;
xrange = dynSys_opts.Xrange;
yrange = dynSys_opts.Yrange;
radius = dynSys_opts.radius;
zero = dynSys_opts.zero;
% -------------------------

% -------------------------
% load simulation parameters
% -------------------------
sim_opts = sim_opts_REPOSITORY(opts.sim);
nrun = sim_opts.nRun;
runtime = sim_opts.runTime;
totaltime = sim_opts.totalTime;
if ~isfield(sim_opts,'X0')
    error('runSimulation_idealFF only works when initial positions of the mass have been defined in the options of simulation')
end;

% -------------------------

% number of time steps per run
nticks = round(totaltime/runtime);

% init matrices
datastate = zeros(nrun, nticks, 4);
dataforce = zeros(nrun, nticks, 2);
dataconverge = nan(nrun,1);


for ii = 1:nrun
        
    % take starting positions in the options of simulation 
    xi = xrange(2)*sim_opts.X0(1,ii);
    yi = yrange(2)*sim_opts.X0(2,ii);
    
    % set mass as the initial state
    state = [xi yi 0 0];  % start at rest
    
    for jj = 1:nticks
        if indeadzone(state, radius, zero)
            break;
        else
            
            pos=[state(1), state(2)];
            force=dynSys_opts.FF(pos');
%             if isfield(dynSys_opts,'stiffness')
%                 stiffness = dynSys_opts.stiffness;
%                 force=-stiffness*pos';
%             elseif isfield(dynSys_opts,'FFGauss')
%                 sigma=dynSys_opts.FFGauss.sigma;
%                 sf=dynSys_opts.FFGauss.sf;
%                 Fg=dynSys_opts.FFGauss.Fg;
%                 force=Fg(pos',sigma,sf);
%             else
%                 error('problem in dynSys_opts');
%             end;
            
            % apply the force to the point mass
            ExternalForce = - force;
            
            % warning: the time argument isn't used when solving the
            % differential equation
            [time, statevector] = ode45(@MBF, [0, runtime], state);
            
            state = statevector(end,:)';
            
            % record data
            datastate(ii, jj, :) = state;
            dataforce(ii, jj, :) = force;
        end
    end
    
    if indeadzone(state, radius, zero)
        dataconverge(ii) = jj;
    end
    
end

sim.State = datastate;
sim.Force = dataforce;
sim.Converge = dataconverge;

% save results
[dirName, fileName] = file_opts_REPOSITORY(opts, 'sim_idealFF');
save(fullfile(dirName, fileName), 'sim');