function simulate_loop(opts)

% -------------------------
% load sampling parameters
% -------------------------
rec_opts = rec_opts_REPOSITORY(opts.rec);
BIN = rec_opts.bin;
WINDOW = rec_opts.window;
OFFSET = rec_opts.offset;
% -------------------------

% -------------------------
% load results of the calibration
% -------------------------
[dirName, fileName] = file_opts_REPOSITORY(opts, 'cal');
load(fullfile(dirName, fileName), 'cal');
RecPoint=cal.RecPoint;
ForceTest=cal.ForceTest;
units=cal.units;
ntrials=cal.testntrials;
% -------------------------

% -------------------------
% load simulation parameters
% -------------------------
sim_opts = sim_opts_REPOSITORY(opts.sim);
nRun = sim_opts.nRun;
runTime = sim_opts.runTime;
totalTime = sim_opts.totalTime;
nTicks = round(totalTime/runTime);
% -------------------------


sim.State = zeros(length(units),numel(WINDOW),numel(OFFSET),numel(BIN), nRun, nTicks, 4,'single');
sim.Force = zeros(length(units),numel(WINDOW),numel(OFFSET),numel(BIN), nRun, nTicks, 2,'single');
sim.Stimulation = zeros(length(units),numel(WINDOW),numel(OFFSET),numel(BIN), nRun, nTicks,'single');
%sim.Activity = zeros(length(units),numel(WINDOW),numel(OFFSET),numel(BIN), nRun, nTicks, nT, nUnit,'single');
sim.Converge = NaN(length(units),numel(WINDOW),numel(OFFSET),numel(BIN), nRun,'single');
sim.TriFail = NaN(length(units),numel(WINDOW),numel(OFFSET),numel(BIN));

for uu=1:length(units),
    
    for ii = 1:numel(BIN) % choose bin size
        
        for jj = 1:numel(WINDOW)    % choose window size
            
            for kk = 1:numel(OFFSET);   % choose offset
                
                recpoint=double(squeeze(RecPoint(uu,jj,kk,ii,:,:))');
                forces=squeeze(ForceTest(uu,jj,kk,ii,:,:,:));
                                
                Sim = runSimulation(recpoint, forces,ntrials, opts);
                
                % store results
                sim.State(uu,jj,kk,ii,:,:,:) = Sim.State;
                sim.Force(uu,jj,kk,ii,:,:,:) = Sim.Force;
                sim.Stimulation(uu,jj,kk,ii,:,:) = Sim.Stimulation;
                %    sim.Activity(uu,jj,kk,ii,:,:,:,:) = Sim.Activity;
                sim.Converge(uu,jj,kk,ii,:) = Sim.Converge;
                sim.TriFail(uu,jj,kk,ii) = Sim.TriFail;
            end
        end
    end
end;

% save results
[dirName, fileName] = file_opts_REPOSITORY(opts, 'sim');
save(fullfile(dirName, fileName), 'sim');
