% Marianna Semprini, adapted from Mussa-Ivaldi
% IIT, December 2010

function [ScaleMatrix, invPHI, MeanD] = calibration(data, rangeF)
%
%  This function performs a PCA on the data in dataset (rows= data item,
%  columns= dimensions). The output is an affine transformation that maps
%  the recorded activity (in a column vector of electrode signals) to a
%  2D force vector as in F = ScaleMatrix*(activity-MeanActivity)

[nT, nTrial, nUnit, nStim] = size(data); % nTrial is the same for each stimulus pattern
meanData = zeros(nT, nUnit, nStim);      % initialization needed for case nUnit == 1
meanData(1:nT,1:nUnit,1:nStim) = squeeze(mean(data,2)); % phi

% Build the matrix PHI = <phi, phi>
PHI = zeros(nStim);
for ii = 1:nStim
    for jj = 1:nStim
         PHI(ii,jj) = sum(sum(squeeze(meanData(:,:,ii)).*squeeze(meanData(:,:,jj))));
    end
end
invPHI = pinv(PHI);

% Project all the calibration responses on the mean calibration responses by least squares approximation
% Collect all the S-dimensional d- vectors in a data matrix X
newData = permute(data,[1 3 2 4]);
newData = reshape(newData, nT, nUnit, nTrial*nStim);
newData = repmat(newData, [1, 1, 1, nStim]);
meanData = repmat(meanData, [1, 1, 1, nTrial*nStim]);
meanData = permute(meanData,[1 2 4 3]);
PSI = squeeze(sum(sum(meanData.*newData,1),2));
X = (invPHI*PSI')'; % matrix of d-vectors

% Calculate the PCs over X
pc = princomp(X)';
pc2 = [pc(1,:); pc(2,:)];  % This is the final 2D projection operator

% Map to 2D by PCA
xydata = pc2*detrend(X,0)'; % remove mean

% find maximum variation along the two dimensions
DX = abs(max(xydata(1,:)) - min(xydata(1,:)));
DY = abs(max(xydata(2,:)) - min(xydata(2,:)));

% Compute the scaling matrix
scale(1,1)= rangeF(1)/DX;
scale(2,2)= rangeF(2)/DY;
scale(1,2)= 0.0; 
scale(2,1) = 0.0;

% Derive the net transformation matrix
ScaleMatrix = scale*pc2;
MeanD = mean(X);


