function [data tax]= createDataSet(data, parameters)
% Function createDataSet resamples data matrix according to parameters
%
% data: (time X maxTrials X nUnits X nStimuli) matrix containing spike count
% parameters: array of 3 elements (ms):
%       - MIN: start point of data collection after stimulation
%       - MAX: end point of data collection after stimulation
%       - BIN: sampling interval
%
% newData: (newTime X maxTrials X nUnits X nStimuli) matrix containing resampled spike count

% Marianna Semprini & Fran�ois Szymanski
% IIT, April 2010

MIN = parameters(1)+1;
% MIN = parameters(1);
MAX = parameters(2);
BIN = parameters(3);
LAG = [MIN:BIN:MAX+1]; % new time vector
% tax=LAG+BIN/2; tax(end)=LAG(end);
tax=LAG(1:end-1)-BIN/2;
[nT, maxTrial, nUnit, nStim] = size(data);

if length(LAG(1:end-1))~=nT % avoid doing the following operations when unncessary
    
    tmpData = reshape(data(MIN:MAX,:,:,:),MAX-MIN+1,maxTrial*nUnit*nStim)';
    timeMat = repmat(MIN:MAX,maxTrial*nUnit*nStim,1);
    tmpData = timeMat.*tmpData;
    
    TmpDataResampled = histc(tmpData, LAG, 2); %the lines of NaN become lines of zeros
    
    % newData = reshape(TmpDataResampled',length(LAG), maxTrial, nUnit, nStim);
    data = reshape(TmpDataResampled(:,1:end-1)',length(LAG(1:end-1)), maxTrial, nUnit, nStim);
end;


% newData = NaN(length(LAG), maxTrial, nUnit, nStim);
%
% for ii = 1:nStim
%     nTrials = dataParams.trialN(ii);
%
%     for jj = 1:nUnit
%
%         for kk = 1:nTrials
%             tmpData = squeeze(data(MIN:MAX,kk,jj,ii));
%             newData(:,kk,jj,ii) = histc(find(tmpData), LAG);
%         end
%     end
% end