% Marianna Semprini
% IIT, December 2010

function activity = record(server, T, dT, units)
% Function record collects electrode signals
%
% s: handle to PLexNet server
% T: time interval for acquisition
% dT: sampling interval for acquisition
% units: matrix containing channel (first row) and unit (second row) number

% activity: firing rate matrix (NofUnits X T/dT)

T = T./1000;    %  convert to sec
dT = dT./1000;  %  convert to sec
data = getData(server, T);

nEl = numel(units)/2;
activity = [];

start = find(data(:,1)==4); % events
start = start(end); % last event
startRecTime = data(start,4)+.001; % 1 ms after stimulation
startNew = find(data(:,4)>=startRecTime); 
endTime = find(data(:,4)>startRecTime+T)-1; 
if isempty(endTime)
    endTime = numel(data(:,4));
else
    endTime = endTime(1);
end
endRecTime = data(endTime,4);
if isempty(startNew)
                                                             %%% SISTEMARE
else
    start = startNew(1);
end
data(:,endTime:end) = [];
data(1:start-1,:) = [];

LAG = [0:dT:T-dT];

for ii = 1:nEl
    ch = units(1,ii);
    u = units(2,ii);
    tmp = data(find((data(:,1)==1)&(data(:,2)==ch)&(data(:,3)==u)),:);
    tmp = tmp(:,4);
    tmp = tmp-repmat(startRecTime, numel(tmp),1);
    if numel(tmp)<=1 % no signal at that electrode
        activity = [activity; zeros(size(LAG))];
    else
        activity = [activity; histc(tmp', LAG)];
    end
end