function handles = runBMI(handles)
% function runBMI runs the BMI:
% the pointmass moves according to the force generated at previous step
% a stimulation pattern is chosen according to current position
% neural activity is recorded and then translated into force

global ExternalForce Mass Damping
ExternalForce = - handles.force;
Mass = handles.mass;
Damping = handles.damping;

% find nex state according to force
[time, state] = ode45(@MBF, [0, handles.runTime], handles.state);

axes(handles.space_axes);
plot(state(1:10:end,1), state(1:10:end,2), '.', 'markeredgecolor', handles.stimulation_color(handles.current_stimulation));
%plot(State(:,1), State(:,2), 'b.');
handles.state = state(end,:);

% det stimulus according to state

handles.tri = delaunay(handles.recPoint(1,:),handles.recPoint(2,:));
handles.current_stimulation = dsearch(handles.recPoint(1,:),handles.recPoint(2,:),handles.tri,handles.state(1),handles.state(2));

% stimulate
if handles.MODE == 1    % experiment mode
    stimulate(handles.current_stimulation, handles.dio);
    % record activity
    handles.activity = record(handles.plexon, handles.T, handles.dT, handles.units); % activity is a (units X time) matrix
 else                    % debug mode
    handles.activity = round(rand(handles.n_REC_electrodes, handles.T/handles.dT));
end
        
% find new force
activity = repmat(handles.activity',[1, 1,handles.n_STIM_patterns]);
F = squeeze(sum(sum(handles.meanData.*activity,1),2)); 
force = handles.scaleMatrix*(handles.invPHI*F - handles.meanD');
handles.force = force';

% plot neural responses
axes(handles.response_axes);
imagesc(handles.activity); colorbar;
axis([1 round(handles.T/handles.dT) 1 handles.n_REC_electrodes]);
set(gca,'xtick',[0:10:round(handles.T/handles.dT)], 'xticklabel', [0:10*handles.dT:handles.T]);
xlabel(['T [steps of ' num2str(handles.dT) ' ms]']);
ylabel('neural responses');

