function compDistInfo_loop(opts)

% -------------------------
% load .mat file
% -------------------------
[dirName, fileName] = file_opts_REPOSITORY(opts, 'dist');
load(fullfile(dirName, fileName));  

trialN=dist.trialN;
TETA=dist.teta;
TC=dist.tc;

optsmi.method='dr';
optsmi.bias='pt';
optsmi.btsp=0;
optsmi.nt=trialN;

opts.trialN=trialN; % for decoDist
nstim=length(trialN);

distmi.trialN=trialN;
distmi.TETA=TETA;
distmi.TC=TC;
distmi.decperf=nan(numel(TETA),numel(TC),nstim);
distmi.I=nan(numel(TETA),numel(TC));
distmi.Y=nan(numel(TETA),numel(TC),sum(trialN),2);
% distmi.decperf2Ddisp=nan(numel(TETA),numel(TC),nstim);
% distmi.I2Ddisp=nan(numel(TETA),numel(TC));
distmi.decperf2Ddist=nan(numel(TETA),numel(TC),nstim);
distmi.I2Ddist=nan(numel(TETA),numel(TC));

for ii = 1:numel(TETA)
    for jj = 1:numel(TC)
        tic;
        sprintf('%s : Info for distances with teta=%d and tc=%d',opts.set,TETA(ii),TC(jj))
        
        D=squeeze(squeeze(dist.D(ii,jj,:,:)));
        
        % decoding performance (original distances)
        decstim=decoDist(D,opts);
        
        deccorrect=decstim==repmat(1:nstim,[max(trialN) 1]);
        distmi.decperf(ii,jj,:)=100*sum(deccorrect)./trialN;
        
        % MI between decoded and actual stim (original distances)
        R=nan([1 size(decstim)]);
        R(1,:,:)=decstim;
        distmi.I(ii,jj) = information(R, optsmi, 'Ish');
        
        try
            % projection in 2D using MDS
            % default option doesnt work with simulated M1 data
            % but works with 'criterion' : 'strain'
            if isfield(opts,'MDScriterion')
                crit=opts.MDScriterion;
            else
                opts.MDScriterion='stress';
                crit='stress';
            end;
            %             [Y,stress,disparities] = mdscale(D,2,'criterion',crit);
            if strcmp(crit,'sammon')
                [I J]=find(D==0);
                z=find(I~=J); I=I(z); J=J(z);
                D(sub2ind(size(D),I,J))=0.1*min(D(D>0));
            end;
            Y = mdscale(D,2,'criterion',crit);
            distmi.Y(ii,jj,:,:)=Y;
            
%             % decoding performance (2D disparities)
%             decstim2Ddisp=decoDist(disparities,opts);
%             deccorrect=decstim2Ddisp==repmat(1:nstim,[max(trialN) 1]);
%             distmi.decperf2Ddisp(ii,jj,:)=100*sum(deccorrect)./trialN;
%             
%             % MI between decoded and actual stim (2D disparities)
%             R2Ddisp=nan([1 size(decstim2Ddisp)]);
%             R2Ddisp(1,:,:)=decstim2Ddisp;
%             distmi.I2Ddisp(ii,jj) = information(R2Ddisp, optsmi, 'Ish');
            
            % compute 2D distances
            D2Ddist=nan(size(D));
            for aa=1:sum(trialN),
                for bb=1:sum(trialN),
                    D2Ddist(aa,bb)=sqrt(sum((Y(aa,:)-Y(bb,:)).^2));
                end;
            end;
            
            % decoding performance (2D distances)
            decstim2Ddist=decoDist(D2Ddist,opts);
            deccorrect=decstim2Ddist==repmat(1:nstim,[max(trialN) 1]);
            distmi.decperf2Ddist(ii,jj,:)=100*sum(deccorrect)./trialN;       
            
            % MI between decoded and actual stim (2D distances)
            R2Ddist=nan([1 size(decstim2Ddist)]);
            R2Ddist(1,:,:)=decstim2Ddist;
            distmi.I2Ddist(ii,jj) = information(R2Ddist, optsmi, 'Ish');
            toc;
        catch
            sprintf('Could not do the MDS.')
        end;
    end
end;

% save results
[dirName, fileName] = file_opts_REPOSITORY(opts, 'distmi');
save(fullfile(dirName, fileName), 'distmi');