function decstim=decoDist(D,opts)
% decode which stimulus elicited each trial
%
% D : matrix of distances
% opts.trialN : number of trial for each stimulus [1 nstim]

trialN = opts.trialN;

decstim=nan(max(trialN),length(trialN));
of1=0;
z=-2;

% replace 0s by a small value. With our low dimensional simulated data,
% it often happens that an identical spike train is elicited by several
% stimuli. In that case there is a 0 distance between the spike train to be
% decoded, and diverse trials corresponding to several stimuli. And because
% 0^-2=infinity, we get an average distance of 0 to these stimuli.
% Replacing 0s by a small value avoid that problem.
D2=D;
D2(D==0)=min(D(D~=0))/100;

% for each trial

for st=1:length(trialN),
    for tr=1:trialN(st)
        
        % measure its distance from each cluster
        dtr=D2(of1+tr,:);
        of2=0;
        avgdtr=nan(1,length(trialN));
        for st2=1:length(trialN)
            dtrtmp=dtr((of2+1):(of2+trialN(st2)));
            
            % remove the distance of the trial to itself
            if st==st2,
                dtrtmp(tr)=[];
            end;
            avgdtr(st2)=mean(dtrtmp.^z)^(1/z);
            of2=of2+trialN(st2);
        end;
        
        % we select the stimulus that elicited the closest cluster
        [minval, I]=min(avgdtr);
        % check if other mimima exist
        minvalidx=find(avgdtr==minval);
        % if more than one minimum
        if numel(minvalidx)>1,
            % select decoded stimulus at random amongst them
            I=minvalidx(ceil(rand*numel(minvalidx)));
        end;
        decstim(tr,st)=I;
    end;
    of1=of1+trialN(st);
end;

% cdec=decstim==repmat(1:12,150,1);
% 100*mean(cdec(:))