function newData = createDataSet(data, parameters)
% Function createDataSet resamples data matrix according to parameters
%
% data: (time X maxTrials X nUnits X nStimuli) matrix containing spike count
% parameters: array of 3 elements (ms):
%       - MIN: start point of data collection after stimulation
%       - MAX: end point of data collection after stimulation
%       - BIN: sampling interval
%
% newData: (newTime X maxTrials X nUnits X nStimuli) matrix containing resampled spike count

% Marianna Semprini & Franois Szymanski
% IIT, April 2010

MIN = parameters(1)+1;  
MAX = parameters(2);
BIN = parameters(3);
LAG = [MIN:BIN:MAX]; % new time vector
[nT, maxTrial, nUnit, nStim] = size(data);

tmpData = reshape(data(MIN:MAX,:,:,:),MAX-MIN+1,maxTrial*nUnit*nStim)';
timeMat = repmat(MIN:MAX,maxTrial*nUnit*nStim,1);
tmpData = timeMat.*tmpData;

TmpDataResampled = histc(tmpData, LAG, 2); %the lines of NaN become lines of zeros

newData = reshape(TmpDataResampled',length(LAG), maxTrial, nUnit, nStim);

% newData = NaN(length(LAG), maxTrial, nUnit, nStim);
%
% for ii = 1:nStim
%     nTrials = dataParams.trialN(ii);
%     
%     for jj = 1:nUnit
%         
%         for kk = 1:nTrials
%             tmpData = squeeze(data(MIN:MAX,kk,jj,ii));
%             newData(:,kk,jj,ii) = histc(find(tmpData), LAG);
%         end
%     end
% end