function createSimulatedDataSet(opts)
% create a simulated data set from the firing rate of an existing one

SUs=opts.SUs;
bin=opts.bin;

% -------------------------
% load data
% -------------------------
[dirName, fileName] = file_opts_REPOSITORY(opts, 'raw mat');
load(fullfile(dirName, fileName)); % load data and dataParams
data=squeeze(data(:,:,SUs,:));

setid=opts.set;
[nt maxtrial nunit nstim] = size(data);
data_orig=data;
ntrial_orig=dataParams.trialN;

% -------------------------
% save original sub data set used for simulating data
% -------------------------
opts.set=['ORIGINAL_' setid];
dataParams.unitIndex=dataParams.unitIndex(:,SUs);
[dirName, fileName] = file_opts_REPOSITORY(opts, 'raw mat');
save(fullfile(dirName, fileName), 'data', 'dataParams');

% -------------------------
% compute firing rates
% -------------------------
edges = 1:bin:nt;
frateall=nan(length(edges),length(SUs),nstim);

for uu = 1:length(SUs)
    for ss=1:nstim
        
        tmp = squeeze(data_orig(:,:,uu,ss));
        new = zeros(length(edges),ntrial_orig(ss));
        for ii = 1:ntrial_orig(ss)
            new(:,ii) = histc(find(tmp(:,ii)),edges);
        end
        
        % This normalizes to the probabilty of a spike in each bin
        frate=mean(new,2);
        frateall(:,uu,ss)=frate;
    end;
end

% -------------------------
% Generate simulated data set
% -------------------------
data=nan([nt maxtrial length(SUs) nstim]);
ntrial=maxtrial*ones(1,nstim);

for uu = 1:length(SUs)
    for ss=1:nstim
        for tt=1:length(edges),
            for tr=1:maxtrial
                isspk=rand<squeeze(frateall(tt,uu,ss));
                trn=[zeros(1,bin-1) isspk];
                trn=trn(randperm(bin));
                data(edges(tt):edges(tt)+bin-1,tr,uu,ss)=trn;
            end;
        end;
    end;
end;

% -------------------------
% save simulated data set
% -------------------------
opts.set=['SIMULATED_' setid];
dataParams.trialN=ntrial;
dataParams.bin=bin;

[dirName, fileName] = file_opts_REPOSITORY(opts, 'raw mat');
save(fullfile(dirName, fileName), 'data', 'dataParams');