function createSimulatedDataSetMixed_FromMultipSets(opts)
% create a simulated data set from the firing rate of an existing one

sets=opts.sets;
bin=opts.bin;
gamma=opts.gamma;

NSTIMS=0;
for ss=1:length(opts.stims),
    NSTIMS=NSTIMS+length(opts.stims{ss});
end;

for ff=1:length(sets)
    opts.set=sets{ff};
    SUs=opts.SUs{ff};
    stims=opts.stims{ff};

% -------------------------
% load data
% -------------------------
[dirName, fileName] = file_opts_REPOSITORY(opts, 'raw mat');
load(fullfile(dirName, fileName)); % load data and dataParams
data=squeeze(data(:,:,SUs,stims));
dataParams.trialN=dataParams.trialN(stims);

% % remove useless stim
% badstim=dataParams.trialN<60;
% if isfield(dataParams,'stimPatterns') && ~isempty(dataParams.stimPatterns), dataParams.stimPatterns(badstim,:)=[]; end;
% dataParams.trialN(badstim)=[];
% data(:,:,:,badstim)=[];

setid=opts.set;
[nt maxtrial nunit nstim] = size(data);
data_orig=data;
ntrial_orig=dataParams.trialN;

% % -------------------------
% % save original sub data set used for simulating data
% % -------------------------
% opts.set=['ORIGINAL_' setid];
dataParams.unitIndex=dataParams.unitIndex(:,SUs);
% [dirName, fileName] = file_opts_REPOSITORY(opts, 'raw mat');
% save(fullfile(dirName, fileName), 'data', 'dataParams');

% -------------------------
% compute firing rates
% -------------------------
edges = 1:bin:nt;
frateall{ff}=nan(length(edges),length(SUs),nstim);

for uu = 1:length(SUs)
    for ss=1:nstim
        
        tmp = squeeze(data_orig(:,:,uu,ss));
        new = zeros(length(edges),ntrial_orig(ss));
        for ii = 1:ntrial_orig(ss)
            new(:,ii) = histc(find(tmp(:,ii)),edges);
        end
        
        % This normalizes to the probabilty of a spike in each bin
        frate=mean(new,2);
        frateall{ff}(:,uu,ss)=frate;
    end;
end
end;

frateall2=nan(length(edges),length(SUs),NSTIMS);
offset=1;
for ff=1:length(sets)
    frateall2(:,:,offset:offset+length(opts.stims{ff})-1)=frateall{ff};
    offset=offset+length(opts.stims{ff});
end;
nstim=NSTIMS;

% make the PSTHs more or less noisy
% gamma=1 : no information, gamma=0 : max info 
% gamma<0 more info! but need to threshold to zero
frateallmix=abs(frateall2+gamma*(repmat(mean(frateall2,3),[1 1 nstim])-frateall2));

% -------------------------
% Generate simulated data set
% -------------------------
maxtrial=150; % 50 for calib and 100 for sim
data=nan([nt maxtrial length(SUs) nstim]);
ntrial=maxtrial*ones(1,nstim);

for uu = 1:length(SUs)
    for ss=1:nstim
        for tt=1:length(edges),
            for tr=1:maxtrial
                isspk=rand<squeeze(frateallmix(tt,uu,ss));
                trn=[zeros(1,bin-1) isspk];
                trn=trn(randperm(bin));
                data(edges(tt):edges(tt)+bin-1,tr,uu,ss)=trn;
            end;
        end;
    end;
end;

% -------------------------
% save simulated data set
% -------------------------
opts.set=['SIM_' num2str(nstim) 'stims_gamma' num2str(round(100*(gamma)))];
dataParams.trialN=ntrial;
dataParams.bin=bin;
dataParams.gamma=gamma;
dataParams=rmfield(dataParams,'unitIndex');
dataParams=rmfield(dataParams,'stimPatterns');

[dirName, fileName] = file_opts_REPOSITORY(opts, 'raw mat');
save(fullfile(dirName, fileName), 'data','dataParams');