function algo2_opts = algo2_opts_REPOSITORY(opt)


% defaults

% % angle between unit vectors used by the distance metric (0: summed population, pi/2: labelled line)
% algo2_opts.distangle=pi/2;
% % time constant of the decaying exponentional kernel used by the distance metric
% algo2_opts.disttc=10;

% The goodness-of-fit criterion to minimize (used by MDSCALE.m)
algo2_opts.MDScrit='strain';
% scaling factor, to ensure the calibration points span the sensory space
algo2_opts.scalfact=3/4;
% take the ideal force at : 0 (default): the RecPoints, 1: the center of
% each region defined by nearest neighbour method on the RecPoints
algo2_opts.ForceFromRegionCenter=1;
% translate points such that the target is located at the interesection
% between 3 regions
algo2_opts.intersectShift=1;


% note : we have 5 ways to compute the Forces
% 2a:  'decode stimulus';
% 2b1: 'weights from normalized inverse distances';
% 2b2: 'weights from correlation between trial distances and calib distances';
% 2b3: 'weights from trial distances x inverse calib distances matrix';
% 2c:  'project trial in 2D using MDS';
% 2s:  'force at position of most similar calibration trial'
        
switch(opt)
    
    %=========
    case 'algo2a'
        algo2_opts.Fcomp = 'decode stimulus';
        
    case 'algo2b1'
        algo2_opts.Fcomp = 'weights from normalized inverse distances';
        algo2_opts.p=10;
        
    case 'algo2b2'
        algo2_opts.Fcomp = 'weights from correlation between trial distances and calib distances';
        
    case 'algo2b3'
        algo2_opts.Fcomp = 'weights from trial distances x inverse calib distances matrix';
        
    case 'algo2c'
        algo2_opts.Fcomp = 'project trial in 2D using MDS';
        algo2_opts.scalfact='ScaleYtoField';
        
    case 'algo2c_ScaleYtoFieldNoShift'
        algo2_opts.Fcomp = 'project trial in 2D using MDS';
        algo2_opts.scalfact='ScaleYtoFieldNoShift';
        
    case 'algo2c_ScaleYtoFieldNoShiftS'
        algo2_opts.Fcomp = 'project trial in 2D using MDS';
        algo2_opts.scalfact='ScaleYtoFieldNoShift';
        algo2_opts.intersectShift=0;
%         algo2_opts.MDScrit='sammon';

        
        
        % try a small scaling to give less importance to badly decoded stim
        % that should be closer to the center
    case 'algo2a_smallscal'
        algo2_opts.Fcomp = 'decode stimulus';
        algo2_opts.scalfact=1/4;
        
    case 'algo2b1_smallscal'
        algo2_opts.Fcomp = 'weights from normalized inverse distances';
        algo2_opts.p=10;
        algo2_opts.scalfact=1/4;

    case 'algo2b2_smallscal'
        algo2_opts.Fcomp = 'weights from correlation between trial distances and calib distances';
        algo2_opts.scalfact=1/4;

    case 'algo2b3_smallscal'
        algo2_opts.Fcomp = 'weights from trial distances x inverse calib distances matrix';
        algo2_opts.scalfact=1/4;
        
        
        
        % try various scaling
    case 'algo2a_scal1'
        algo2_opts.Fcomp = 'decode stimulus';
        algo2_opts.scalfact=1/5;
        
    case 'algo2b3_scal1'
        algo2_opts.Fcomp = 'weights from trial distances x inverse calib distances matrix';
        algo2_opts.scalfact=1/5;
        
    case 'algo2a_scal2'
        algo2_opts.Fcomp = 'decode stimulus';
        algo2_opts.scalfact=2/5;
        
    case 'algo2b3_scal2'
        algo2_opts.Fcomp = 'weights from trial distances x inverse calib distances matrix';
        algo2_opts.scalfact=2/5;
        
    case 'algo2a_scal3'
        algo2_opts.Fcomp = 'decode stimulus';
        algo2_opts.scalfact=3/5;
        
    case 'algo2b3_scal3'
        algo2_opts.Fcomp = 'weights from trial distances x inverse calib distances matrix';
        algo2_opts.scalfact=3/5;
        
    case 'algo2a_scal4'
        algo2_opts.Fcomp = 'decode stimulus';
        algo2_opts.scalfact=4/5;
        
    case 'algo2b3_scal4'
        algo2_opts.Fcomp = 'weights from trial distances x inverse calib distances matrix';
        algo2_opts.scalfact=4/5;
        
        
    case 'algo2a_ScaleYtoField'
        algo2_opts.Fcomp = 'decode stimulus';
        algo2_opts.scalfact='ScaleYtoField';
        
    case 'algo2a_ScaleYtoFieldNoShift'
        algo2_opts.Fcomp = 'decode stimulus';
        algo2_opts.scalfact='ScaleYtoFieldNoShift';
        
    case 'algo2a_ScaleYtoFieldNoShiftS'
        algo2_opts.Fcomp = 'decode stimulus';
        algo2_opts.scalfact='ScaleYtoFieldNoShift';
        algo2_opts.intersectShift=0;
        
    case 'algo2a0_ScaleYtoFieldNoShiftS'
        algo2_opts.Fcomp = 'decode stimulus';
        algo2_opts.scalfact='ScaleYtoFieldNoShift';
        algo2_opts.intersectShift=0;
        algo2_opts.ForceFromRegionCenter=0;

        
        
    case 'algo2s_ScaleYtoFieldNoShiftS'
        algo2_opts.Fcomp = 'force at position of most similar calibration trial';
        algo2_opts.scalfact='ScaleYtoFieldNoShift';
        algo2_opts.intersectShift=0;
        
        
end