function dynSys_opts = dynSys_opts_REPOSITORY(opt)
% function dynSys_opts set Dynamic Shaping parameters according to opt
%
% opt: specifies experiment type
%
% dynSys_opts: Dynamic System parameters
%
% Marianna Semprini & Fran�ois Szymanski
% IIT, May 2010

switch(opt)
    
    %=========
    case 'dynSys1'
        %=========
        dynSys_opts.stiffness = [4 0; 0 4];
        dynSys_opts.mass = [10 0; 0 10];
        dynSys_opts.damping = [15 0; 0 15];
        dynSys_opts.Xrange = [-10 10];
        dynSys_opts.Yrange = [-10 10];
        dynSys_opts.radius = 2;
        dynSys_opts.zero = [0 0];
        
        dynSys_opts.FF=@(P)(-dynSys_opts.stiffness*P);

        
        % reminder: the damping ratio is zeta=damping/(2*sqrt(stiffness*mass))
        % when the system is over-damped (zeta>1), it reaches equilibrium
        % without oscillations
        %=========
    case 'dynSys_damp13' % zeta=1.03
        %=========
        dynSys_opts.stiffness = [4 0; 0 4];
        dynSys_opts.mass = [10 0; 0 10];
        dynSys_opts.damping = 13*[1 0; 0 1];
        dynSys_opts.Xrange = 5*[-10 10];
        dynSys_opts.Yrange = 5*[-10 10];
        dynSys_opts.radius = 2;
        dynSys_opts.zero = [0 0];
        
        dynSys_opts.FF=@(P)(-dynSys_opts.stiffness*P);
        
        %=========
    case 'dynSys_damp19' % zeta=1.5
        %=========
        dynSys_opts.stiffness = [4 0; 0 4];
        dynSys_opts.mass = [10 0; 0 10];
        dynSys_opts.damping = 19*[1 0; 0 1];
        dynSys_opts.Xrange = 5*[-10 10];
        dynSys_opts.Yrange = 5*[-10 10];
        dynSys_opts.radius = 2;
        dynSys_opts.zero = [0 0];
        
        dynSys_opts.FF=@(P)(-dynSys_opts.stiffness*P);
        
        %=========
    case 'dynSys_damp25' % zeta=1.98
        %=========
        dynSys_opts.stiffness = [4 0; 0 4];
        dynSys_opts.mass = [10 0; 0 10];
        dynSys_opts.damping = 25*[1 0; 0 1];
        dynSys_opts.Xrange = 5*[-10 10];
        dynSys_opts.Yrange = 5*[-10 10];
        dynSys_opts.radius = 2;
        dynSys_opts.zero = [0 0];
        
        dynSys_opts.FF=@(P)(-dynSys_opts.stiffness*P);
        
        %=========
    case 'dynSys_damp31' % zeta=1.98
        %=========
        dynSys_opts.stiffness = [4 0; 0 4];
        dynSys_opts.mass = [10 0; 0 10];
        dynSys_opts.damping = 31*[1 0; 0 1];
        dynSys_opts.Xrange = 5*[-10 10];
        dynSys_opts.Yrange = 5*[-10 10];
        dynSys_opts.radius = 2;
        dynSys_opts.zero = [0 0];
        
        dynSys_opts.FF=@(P)(-dynSys_opts.stiffness*P);
        
        %=========
    case 'dynSys_damp37' % zeta=1.98
        %=========
        dynSys_opts.stiffness = [4 0; 0 4];
        dynSys_opts.mass = [10 0; 0 10];
        dynSys_opts.damping = 37*[1 0; 0 1];
        dynSys_opts.Xrange = 5*[-10 10];
        dynSys_opts.Yrange = 5*[-10 10];
        dynSys_opts.radius = 2;
        dynSys_opts.zero = [0 0];
        
        dynSys_opts.FF=@(P)(-dynSys_opts.stiffness*P);
        
        % non-invertible FF: gradient of a Gaussian potential function (1992
        % Biological Cybernetics Sandro's paper)
    case 'dynSys_Gauss' 
        %=========
        % dynSys_opts.stiffness = [4 0; 0 4]; removed so it crashes if one
        % tries to use it       
        dynSys_opts.mass = [10 0; 0 10];
        dynSys_opts.damping = 13*[1 0; 0 1];
        dynSys_opts.Xrange = 5*[-10 10];
        dynSys_opts.Yrange = 5*[-10 10];
        dynSys_opts.radius = 2;
        dynSys_opts.zero = [0 0];
        
        dynSys_opts.FFpar.attpos=[0; 0];
        dynSys_opts.FFpar.attsigma=(1/2)*max(dynSys_opts.Xrange);
        dynSys_opts.FFpar.attint=1.6492e+03; % in this way the recForce in the region close to the target is the same as in dynSys_damp13...

        %         dynSys_opts.FFpar.Fgauss=@(P,targ,sigma,int)(int*-2*(P-targ)*exp(-((P-targ)'*(P-targ))/sigma^2)/sigma^2);        
        %         dynSys_opts.FF=@(P)(dynSys_opts.FFpar.Fgauss(P,dynSys_opts.FFpar.attpos,dynSys_opts.FFpar.attsigma,dynSys_opts.FFpar.attint));

        % Gaussian (potential)
        dynSys_opts.FFpar.gauss=@(p,targ,sigma)(exp(-((p-targ)'*(p-targ))/sigma^2)/sigma^2);
        % Derivative of the Gaussian that describes the Forces
        dynSys_opts.FFpar.dgauss=@(p,targ,sigma)(-2*(p-targ)*dynSys_opts.FFpar.gauss(p,targ,sigma));
        % Weighted sum of the Gaussians
        dynSys_opts.FFpot=@(P)(dynSys_opts.FFpar.attint*dynSys_opts.FFpar.gauss(P,dynSys_opts.FFpar.attpos,dynSys_opts.FFpar.attsigma));
        % FORCE FIELD: Weighted sum of the Gaussian derivatives
        dynSys_opts.FF=@(P)(dynSys_opts.FFpar.attint*dynSys_opts.FFpar.dgauss(P,dynSys_opts.FFpar.attpos,dynSys_opts.FFpar.attsigma));
   
        
    case 'dynSys_Dipole'
        %=========
        % dynSys_opts.stiffness = [4 0; 0 4]; removed so it crashes if one
        % tries to use it       
        dynSys_opts.mass = [10 0; 0 10];
        dynSys_opts.damping = 13*[1 0; 0 1];
        dynSys_opts.Xrange = 5*[-10 10];
        dynSys_opts.Yrange = 5*[-10 10];
        dynSys_opts.radius = 2;
        
        dynSys_opts.FFpar.attpos=[10; 0];
        dynSys_opts.FFpar.attsigma=(3/4)*max(dynSys_opts.Xrange);
        dynSys_opts.FFpar.attint=0.3*(282.8427/0.0343);
        dynSys_opts.FFpar.reppos=[-10; 0];
        dynSys_opts.FFpar.repsigma=dynSys_opts.FFpar.attsigma/2;
        dynSys_opts.FFpar.repint=-2*dynSys_opts.FFpar.attint/3;
        
        
        % Gaussian (potential)
        dynSys_opts.FFpar.gauss=@(p,targ,sigma)(exp(-((p-targ)'*(p-targ))/sigma^2)/sigma^2);
        % Derivative of the Gaussian that describes the Forces
        dynSys_opts.FFpar.dgauss=@(p,targ,sigma)(-2*(p-targ)*dynSys_opts.FFpar.gauss(p,targ,sigma));
        % Weighted sum of the Gaussians
        dynSys_opts.FFpot=@(P)(dynSys_opts.FFpar.attint*dynSys_opts.FFpar.gauss(P,dynSys_opts.FFpar.attpos,dynSys_opts.FFpar.attsigma)+dynSys_opts.FFpar.repint*dynSys_opts.FFpar.gauss(P,dynSys_opts.FFpar.reppos,dynSys_opts.FFpar.repsigma));
        % FORCE FIELD: Weighted sum of the Gaussian derivatives
        dynSys_opts.FF=@(P)(dynSys_opts.FFpar.attint*dynSys_opts.FFpar.dgauss(P,dynSys_opts.FFpar.attpos,dynSys_opts.FFpar.attsigma)+dynSys_opts.FFpar.repint*dynSys_opts.FFpar.dgauss(P,dynSys_opts.FFpar.reppos,dynSys_opts.FFpar.repsigma));
        
        dynSys_opts.zero = nan;

end