function [dirName, fileName] = file_opts_REPOSITORY(opts, type)
% function file_opts_REPOSITORY return directory and creates filename according to type
%
% opts: contains information about the data
% type: specifies the kind of data
%
% dirName: directory associated to the type of data
% fileName: filename
%
% Marianna Semprini & Fran�ois Szymanski
% IIT, May 2010

dirs = dir_opts_REPOSITORY;

switch type
    % Original .plx data:
    case 'plx'
        dirName  = dirs.dirPlxData;
        fileName = [opts.set '.plx'];
        
        % Raw .mat data:
    case 'raw mat'
        dirName  = dirs.dirMatData ;
        fileName = [opts.set '.mat'];
        
        % Mutual Information between the Stimulus and the Single Unit response
    case 'MI stim SU'
        dirName  = dirs.dirMIStimSU;
        fileName = [opts.set '_' opts.rec '_' opts.info '_MIStimSU.mat'];
        
        % result of the calibration of the dBMI
    case 'cal'
        dirName  = dirs.dirCalibration;
        fileName = [opts.set '_' opts.rec '_' opts.cal '_' opts.algo '_' opts.dynSys];
        
        % result of the simulation of the dBMI
    case 'sim'
        dirName  = dirs.dirSimulation;
        fileName = [opts.set '_' opts.rec '_' opts.cal '_' opts.algo '_' opts.dynSys '_' opts.sim];
        
        
        % result of the simulation in ideal FF
    case 'sim_idealFF'
        dirName  = dirs.dirSimulation;
        fileName = ['IdealFF_' opts.dynSys '_' opts.sim];
        
        % Mutual Information between the Stimulus and the Force applied on the point mass
    case 'infoForce'
        dirName  = dirs.dirInfoForces;
        fileName = [opts.set '_' opts.rec '_' opts.cal '_' opts.algo '_' opts.dynSys '_' opts.MIForce];
        
        % Mutual Information between the Stimulus and the Force applied on the point mass
    case 'infoForceFromTraj'
        dirName  = dirs.dirInfoForcesFromTraj;
        fileName = [opts.set '_' opts.rec '_' opts.cal '_' opts.algo '_' opts.dynSys '_' opts.sim '_' opts.MIForce];
        
        % distances between multineuron spike trains
    case 'dist'
        dirName  = dirs.dirDist;
        fileName = [opts.set '_' opts.dist];
        
        % distances between multineuron spike trains
    case 'disttmp'
        dirName  = dirs.dirDist;
        fileName = [opts.set '_' opts.dist '_Ncal' num2str(opts.trialN(1))];
        
    case 'DtrAllTest'
        dirName  = dirs.dirDist;
        cal_opts = cal_opts_REPOSITORY(opts.cal);
        fileName = [opts.set '_' opts.dist '_Ncal' num2str(cal_opts.nCalibrations)  '_testVScal'];
        
    case 'distmi'
        dirName  = dirs.dirDist;
        fileName = [opts.set '_' opts.dist '_MI_MDScriterion_' opts.MDScriterion];
        
        
end

if ~isdir(dirName)
    mkdir(dirName);
end;


