clear; clc;

% getsetList;
% getSimMixSetList;
% getSim2DM1SetList;
getSetListMomo;

dirs = dir_opts_REPOSITORY;
savefigs=0;

opts.dist='dist1';
MDScriterion={'metricstress','metricsstress','sammon','strain','sstress'};
opts.MDScriterion=MDScriterion{1};
dist_opts = dist_opts_REPOSITORY(opts.dist);
TETA = round(180*dist_opts.teta/pi);
TC = dist_opts.tc;


%% load info data

Dttls={'dissimilarities','2D distances','difference'};
Pttls={'MI (bits)', 'decoding (% correct)'};

I=nan(length(setList),length(TETA),length(TC));
I2Ddisp=nan(size(I));
I2Ddist=nan(size(I));
decperf=nan(size(I));
decperf2Ddisp=nan(size(I));
decperf2Ddist=nan(size(I));

for ff=1:length(setList)
    opts.set = setList{ff};
    disp(opts.set);
    
    [dirName, fileName] = file_opts_REPOSITORY(opts, 'distmi');
    load(fullfile(dirName, fileName));
    
    I(ff,:,:)=distmi.I;
    I2Ddisp(ff,:,:)=distmi.I2Ddisp;
    I2Ddist(ff,:,:)=distmi.I2Ddist;
    decperf(ff,:,:)=distmi.decperf;
    decperf2Ddisp(ff,:,:)=distmi.decperf2Ddisp;
    decperf2Ddist(ff,:,:)=distmi.decperf2Ddist;
end;


%% plot dissimilarities results as a function of 2D projected results

figure;
set(gcf,'pos',[560   500   960   444]);

subplot(1,2,1)
plot(I(:),I2Ddist(:),'.')
% plot(I(:,1,1),I2Ddist(:,1,1),'.')
xlabel(Dttls{1},'fontsize',18);
ylabel(Dttls{2},'fontsize',18);
title(Pttls{1},'fontsize',20);
axis([min(I2Ddist(:)) max(I(:)) min(I2Ddist(:)) max(I(:))])
axis square;
grid on;
hold on;
plot(xlim,xlim,'--')

subplot(1,2,2)
plot(decperf(:),decperf2Ddist(:),'.')
% plot(decperf(:,1,1),decperf2Ddist(:,1,1),'.')
xlabel(Dttls{1},'fontsize',18);
ylabel(Dttls{2},'fontsize',18);
title(Pttls{2},'fontsize',20);
axis([min(decperf2Ddist(:)) max(decperf(:)) min(decperf2Ddist(:)) max(decperf(:))])
axis square;
grid on;
hold on;
plot(xlim,xlim,'--')

if savefigs
    set(gcf,'color',[1 1 1]);
    fname=['dissim2Ddistscatter_all_' opts.set];
    export_fig(fullfile(dirs.plotdist,[fname '.eps']));
end;
    
%% find good data sets and parameters

goodsetsMI=[];
goodsetsdec=[];
goodparMI=zeros(length(TETA),length(TC));
goodpardec=zeros(length(TETA),length(TC));

for ff=1:length(setList),
    Itmp=squeeze(I2Ddist(ff,:,:));
    goodparMI=goodparMI+(Itmp>0.2);
    if sum(Itmp(:)>0.2),
        goodsetsMI=[goodsetsMI ff];
    end;
    
    dectmp=squeeze(decperf2Ddist(ff,:,:));
    goodpardec=goodpardec+(dectmp>45);
    if sum(dectmp(:)>45),
        goodsetsdec=[goodsetsdec ff];
    end;
end;


%% plot information separately for each data set

figure;

ff=1;
% for ff= 1:5 % 15 %goodsetsdec(5) 
    opts.set = setList{ff};
    disp(opts.set);
    clf;
    
    set(gcf,'pos',[160         261        1376         539]);
    
    h(1)=subplot(2,3,1);
    imagescnan(squeeze(decperf(ff,:,:)));
    set(gca,'ydir','normal','ytick',1:length(TETA),'yticklabel',num2str(TETA'),'xtick',1:length(TC),'xticklabel',num2str(TC'))
    colorbar;
    ylabel('teta','fontsize',16); xlabel('tc','fontsize',16);
    title([Dttls{1} ': ' Pttls{2}],'fontsize',16);
    
    h(2)=subplot(2,3,2);
    imagescnan(squeeze(decperf2Ddist(ff,:,:)));
    set(gca,'ydir','normal','ytick',1:length(TETA),'yticklabel',num2str(TETA'),'xtick',1:length(TC),'xticklabel',num2str(TC'))
    colorbar;
    title([Dttls{2} ': ' Pttls{2}],'fontsize',16);
    
    h(3)=subplot(2,3,3);
    imagescnan(squeeze(decperf(ff,:,:))-squeeze(decperf2Ddist(ff,:,:)));
    set(gca,'ydir','normal','ytick',1:length(TETA),'yticklabel',num2str(TETA'),'xtick',1:length(TC),'xticklabel',num2str(TC'))
    colorbar;
    title([Dttls{3} ': ' Pttls{2}],'fontsize',16);
    caxis(max(abs(caxis))*[-1 1])

    h(4)=subplot(2,3,4);
    imagescnan(squeeze(I(ff,:,:)));
    set(gca,'ydir','normal','ytick',1:length(TETA),'yticklabel',num2str(TETA'),'xtick',1:length(TC),'xticklabel',num2str(TC'))
    colorbar;
    ylabel('teta','fontsize',16); xlabel('tc','fontsize',16);
    title([Dttls{1} ': ' Pttls{1}],'fontsize',16);
    
    h(5)=subplot(2,3,5);
    imagescnan(squeeze(I2Ddist(ff,:,:)));
    set(gca,'ydir','normal','ytick',1:length(TETA),'yticklabel',num2str(TETA'),'xtick',1:length(TC),'xticklabel',num2str(TC'))
    colorbar;
    title([Dttls{2} ': ' Pttls{1}],'fontsize',16);
    
    h(6)=subplot(2,3,6);
    imagescnan(squeeze(I(ff,:,:))-squeeze(I2Ddist(ff,:,:)));
    set(gca,'ydir','normal','ytick',1:length(TETA),'yticklabel',num2str(TETA'),'xtick',1:length(TC),'xticklabel',num2str(TC'))
    colorbar;
    title([Dttls{3} ': ' Pttls{1}],'fontsize',16);
    caxis(max(abs(caxis))*[-1 1])

    cax=[+inf -inf];
    for ii=1:2,
        caxtmp=get(h(ii),'clim');
        cax(1)=min([cax(1) caxtmp(1)]);
        cax(2)=max([cax(2) caxtmp(2)]);
    end;
    for ii=1:2,
        set(h(ii),'clim',cax);
    end;
    cax=[+inf -inf];
    for ii=4:5,
        caxtmp=get(h(ii),'clim');
        cax(1)=min([cax(1) caxtmp(1)]);
        cax(2)=max([cax(2) caxtmp(2)]);
    end;
    for ii=4:5,
        set(h(ii),'clim',cax);
    end;
    
    if savefigs
        set(gcf,'color',[1 1 1]);
        fname=['dissim2DdistImage_' opts.set];
        export_fig(fullfile(dirs.plotdist,[fname '.eps']));
    end;

%     pause;
% end;

%% plot Distances

ff= 1 %15;
% ff=goodsetsdec(7);
ii=4;
jj=4;

opts.set = setList{ff};
disp(opts.set);

[dirName, fileName] = file_opts_REPOSITORY(opts, 'dist');
load(fullfile(dirName, fileName));
dist.D(dist.D(:)==0)=nan;

figure; 
set(gcf,'pos',[560   377   761   567]);
% for ii=1:length(TETA),
%     for jj=1:length(TC),
        imagescnan(squeeze(dist.D(ii,jj,:,:)));
%         caxis([1.5*min(dist.D(:)) 0.75*max(dist.D(:))]);
        colorbar;
        hold on;
        for ss=1:length(dist.trialN)-1,
            plot(sum(dist.trialN(1:ss))*[1 1], [1 sum(dist.trialN)],'w','linewidth',3)
            plot([1 sum(dist.trialN)], sum(dist.trialN(1:ss))*[1 1 ],'w','linewidth',3)
        end;
        title(['Distances for ' strrep(opts.set,'_','-') ' with teta=' num2str(TETA(ii)) ' and tc=' num2str(TC(jj)) 'ms'],'fontsize',15,'fontweight','bold');
        xlabel('trial'); ylabel('trial');
        
        if savefigs
            set(gcf,'color',[1 1 1]);
            fname=['Distances_' opts.set '_teta' num2str(TETA(ii)) '_tc' num2str(TC(jj))];
            export_fig(fullfile(dirs.plotdist,[fname '.eps']));
        end;
%         pause;
%     end;
% end;

%% plot info avg

figure;
% setsidx=1:length(setList); fname='dissim2DdistImage_All';
setsidx=goodsetsdec; fname='dissim2DdistImage_goodsets';

set(gcf,'pos',[160         261        1376         539]);

h(1)=subplot(2,3,1);
imagescnan(squeeze(nanmean(decperf(setsidx,:,:),1)));
set(gca,'ydir','normal','ytick',1:length(TETA),'yticklabel',num2str(TETA'),'xtick',1:length(TC),'xticklabel',num2str(TC'))
colorbar;
ylabel('teta','fontsize',16); xlabel('tc','fontsize',16);
title([Dttls{1} ': ' Pttls{2}],'fontsize',16);

h(2)=subplot(2,3,2);
imagescnan(squeeze(nanmean(decperf2Ddist(setsidx,:,:),1)));
set(gca,'ydir','normal','ytick',1:length(TETA),'yticklabel',num2str(TETA'),'xtick',1:length(TC),'xticklabel',num2str(TC'))
colorbar;
title([Dttls{2} ': ' Pttls{2}],'fontsize',16);

h(3)=subplot(2,3,3);
imagescnan(squeeze(nanmean(decperf(setsidx,:,:),1))-squeeze(nanmean(decperf2Ddist(setsidx,:,:),1)));
set(gca,'ydir','normal','ytick',1:length(TETA),'yticklabel',num2str(TETA'),'xtick',1:length(TC),'xticklabel',num2str(TC'))
colorbar;
title([Dttls{3} ': ' Pttls{2}],'fontsize',16);
caxis(max(abs(caxis))*[-1 1])

h(4)=subplot(2,3,4);
imagescnan(squeeze(nanmean(I(setsidx,:,:),1)));
set(gca,'ydir','normal','ytick',1:length(TETA),'yticklabel',num2str(TETA'),'xtick',1:length(TC),'xticklabel',num2str(TC'))
colorbar;
ylabel('teta','fontsize',16); xlabel('tc','fontsize',16);
title([Dttls{1} ': ' Pttls{1}],'fontsize',16);

h(5)=subplot(2,3,5);
imagescnan(squeeze(nanmean(I2Ddist(setsidx,:,:),1)));
set(gca,'ydir','normal','ytick',1:length(TETA),'yticklabel',num2str(TETA'),'xtick',1:length(TC),'xticklabel',num2str(TC'))
colorbar;
title([Dttls{2} ': ' Pttls{1}],'fontsize',16);

h(6)=subplot(2,3,6);
imagescnan(squeeze(nanmean(I(setsidx,:,:),1))-squeeze(nanmean(I2Ddist(setsidx,:,:),1)));
set(gca,'ydir','normal','ytick',1:length(TETA),'yticklabel',num2str(TETA'),'xtick',1:length(TC),'xticklabel',num2str(TC'))
colorbar;
title([Dttls{3} ': ' Pttls{1}],'fontsize',16);
caxis(max(abs(caxis))*[-1 1])

cax=[+inf -inf];
for ii=1:2,
    caxtmp=get(h(ii),'clim');
    cax(1)=min([cax(1) caxtmp(1)]);
    cax(2)=max([cax(2) caxtmp(2)]);
end;
for ii=1:2,
    set(h(ii),'clim',cax);
end;
cax=[+inf -inf];
for ii=4:5,
    caxtmp=get(h(ii),'clim');
    cax(1)=min([cax(1) caxtmp(1)]);
    cax(2)=max([cax(2) caxtmp(2)]);
end;
for ii=4:5,
    set(h(ii),'clim',cax);
end;

if savefigs
    set(gcf,'color',[1 1 1]);
    export_fig(fullfile(dirs.plotdist,[fname '.eps']));
end;

%% plot 2D projection

figure;
% ff=goodsetsdec(7);
ff= 1 %15;
ii=4;
jj=4;

% for ff=goodsetsdec(6)
%     for ii=1:length(TETA)
%         for jj=1:length(TC)
            
            clf;
            
            opts.set = setList{ff};
            disp(opts.set);
            
            [dirName, fileName] = file_opts_REPOSITORY(opts, 'distmi');
            load(fullfile(dirName, fileName));
            
            Y=squeeze(distmi.Y(ii,jj,:,:));
            trialN=distmi.trialN;
            
            colz=jet; %{'b','g','r','m'};
            labz=num2str((1:length(trialN))'); %{'1','2','3','4'};
            
            hold on;
            offset=1;
            for ss=1:length(trialN),
%                 plot(Y(offset:offset+trialN(ss)-1,1),Y(offset:offset+trialN(ss)-1,2),'o', 'MarkerEdgeColor',colz{ss},'MarkerFaceColor',colz{ss},'MarkerSize',4)
                plot(Y(offset:offset+trialN(ss)-1,1),Y(offset:offset+trialN(ss)-1,2),'o', 'MarkerEdgeColor',colz(ss*6,:),'MarkerFaceColor',colz(ss*6,:),'MarkerSize',6)
                offset=offset+trialN(ss)-1;               
            end;
            legend(labz)
            title(['projection in 2D for ' strrep(setList{ff},'_','-') ' with teta=' num2str(TETA(ii)) ' and tc=' num2str(TC(jj)) 'ms'],'fontsize',12,'fontweight','bold')
            
            TETA(ii)
            TC(jj)
            decperf(ff,ii,jj)
            decperf2Ddist(ff,ii,jj)
            I(ff,ii,jj)
            I2Ddist(ff,ii,jj)
            
            if savefigs
                set(gcf,'color',[1 1 1]);
                fname=['2DProj_' opts.set '_teta' num2str(TETA(ii)) '_tc' num2str(TC(jj))];
                export_fig(fullfile(dirs.plotdist,[fname '.eps']));
            end;
%             pause;
%         end;
%     end;
% end;