clear; clc;
dirs = dir_opts_REPOSITORY;
savefigs=0;

getSimMixSetList; setList=setList(16:20)
% algos = {'algo1','algo2','algo2b','algo2c','algo2d','algo2e','algo2f','algo2g','algo2h'};
% algos = {'algo1','algo2g','algo2i'};
algos = {'algo1','algo2j'};

dynSys={'dynSys_damp13','dynSys_damp19','dynSys_damp25','dynSys_damp31','dynSys_damp37'};
gamma=[0 0.25 0.50 0.75 1];
visc=[13 29 25 31 37];

opts.rec = 'recsimmix';
opts.cal='cal1';
opts.dynSys=dynSys{1};
opts.sim = 'sim2';

uu = 1; % set of SUs
ii = 1; % bin
jj = 1; % window
kk = 1; % offset

% -------------------------
% load sampling parameters
% -------------------------
rec_opts = rec_opts_REPOSITORY(opts.rec);
BIN = rec_opts.bin;
WINDOW = rec_opts.window;
OFFSET = rec_opts.offset;

% -------------------------
% load dynamical system parameters
% -------------------------
dynSys_opts = dynSys_opts_REPOSITORY(opts.dynSys);
Stiffness = dynSys_opts.stiffness;
Mass = dynSys_opts.mass;
Damping = dynSys_opts.damping;
Xrange = dynSys_opts.Xrange;
Yrange = dynSys_opts.Yrange;
Radius = dynSys_opts.radius;
Zero = dynSys_opts.zero;
% -------------------------

MIFopt = {'FxFy2','RT2','AC2'}; infotyp='infoForceFromTraj';
% MIFopt = {'FxFy1','RT1','AC1'}; infotyp='infoForce';
MIForceLabels = {'I(S; [Fx,Fy])', 'I(S;[\rho, \theta])',  'I(\Thetaexp; \Theta)'};
MIForce = NaN(length(MIFopt),length(setList),length(algos));
PerfLabel = {'rate of convergences', 'number of steps to convergence'};
nbconv = NaN(length(setList),length(algos));
nbstp = NaN(length(setList),length(algos));

for ff = 1:length(setList)
    
    opts.set = setList{ff};
    
    for aa=1:length(algos)
        opts.algo = algos{aa};
        
        for mm=1:length(MIFopt)
            opts.MIForce = MIFopt{mm};
            [dirName, fileName] = file_opts_REPOSITORY(opts, infotyp);
            load(fullfile(dirName, fileName));
            MIForce(mm,ff,aa) = squeeze(I(uu,jj,kk,ii));
        end;
        
        [dirName, fileName] = file_opts_REPOSITORY(opts, 'sim');
        load(fullfile(dirName, fileName));
        conv = squeeze(sim.Converge(uu,jj,kk,ii,:));
        nbconv(ff,aa) =round(100*sum(~isnan(conv(:)))/length(conv(:)));
        nbstp(ff,aa) =round(mean(conv(~isnan(conv))));
    end;
end;

%%

figure;
set(gcf,'pos',[275         311        1182         600])

subplot(2,3,1)
plot(nbconv,'-*')
set(gca,'xtick',1:length(gamma),'xticklabel',num2str(gamma'))
title(PerfLabel{1})
ylabel('%')
xlabel('\gamma')

subplot(2,3,2)
plot(nbstp,'-*')
set(gca,'xtick',1:length(gamma),'xticklabel',num2str(gamma'))
title(PerfLabel{2})
xlabel('\gamma')
legend(algos,'location','northwest')

for mm=1:length(MIFopt)
    subplot(2,3,3+mm)
    plot(squeeze(MIForce(mm,:,:)),'-*')
    set(gca,'xtick',1:length(gamma),'xticklabel',num2str(gamma'))
    title(MIForceLabels{mm})
    xlabel('\gamma')
end;

if savefigs
    set(gcf,'color',[1 1 1])
    fname='AlgoPerfComp_3stims_2g';
    export_fig(fullfile(dirs.plotNIPS,[fname '.eps']));
    export_fig(fullfile(dirs.plotNIPS,[fname '.png']));
    close;
end;