% Plot Force vectors from the test set at the location corresponding to the
% stimulus that elicited them

clear; clc;
dirs = dir_opts_REPOSITORY;
savefigs=0;

% getsetList;
% getSimMixSetList;
getSim2DM1SetList;
% getSetListMomo;

gamma=[0 0.25 0.50 0.75 1];
visc=[13 29 25 31 37];

dynSys={'dynSys_damp13','dynSys_damp19','dynSys_damp25','dynSys_damp31','dynSys_damp37'};
% dynSys={'dynSys1'};

% algos={'algo1','algo2a','algo2b1','algo2b2','algo2b3','algo2a_smallscal','algo2b1_smallscal','algo2b2_smallscal','algo2b3_smallscal'};
algos={'algo1','algo2a_ScaleYtoField','algo2c'};
% algos={'algo1','algo2a_scal1','algo2a_scal2','algo2a_scal3','algo2a_scal4'};

ff=1;

for aa = length(algos)

    
%     opts.rec = 'recsimmix';
%     opts.rec='recsim2DM1';
    opts.rec='recsim2DM1_20ms';

    opts.algo = algos{aa};

    
    uu = 1; % set of SUs
    ii = 1; % bin
    jj = 1; % window
    kk = 1; % offset
    
    opts.cal='cal1';
%     opts.cal='cal1_mindecod50b';

    opts.dynSys=dynSys{1};
    opts.sim = 'sim2';
    
    % -------------------------
    % load sampling parameters
    % -------------------------
    rec_opts = rec_opts_REPOSITORY(opts.rec);
    BIN = rec_opts.bin;
    WINDOW = rec_opts.window;
    OFFSET = rec_opts.offset;
    
    % -------------------------
    % load dynamical system parameters
    % -------------------------
    dynSys_opts = dynSys_opts_REPOSITORY(opts.dynSys);
    Stiffness = dynSys_opts.stiffness;
    Mass = dynSys_opts.mass;
    Damping = dynSys_opts.damping;
    Xrange = dynSys_opts.Xrange;
    Yrange = dynSys_opts.Yrange;
    Radius = dynSys_opts.radius;
    Zero = dynSys_opts.zero;
    % -------------------------
    
    % for ff=ffs
    % -------------------------
    % select data set
    % -------------------------
    opts.set = setList{ff};
    
    % -------------------------
    % load calibration file
    % -------------------------
    [dirName, fileName] = file_opts_REPOSITORY(opts, 'cal');
    load(fullfile(dirName, fileName));
    ntrials=cal.testntrials;
    nstims=length(cal.testntrials);
    
    % -------------------------
    % load simulation performances to display on figure
    % -------------------------
    
% %     MIFopt = {'FxFy2','RT2','AC2'}; infotyp='infoForceFromTraj';
%     MIFopt = {'FxFy2','RT2','AC2'}; infotyp='infoForce';
%     MIForceLabels = {'I(S; [Fx,Fy])', 'I(S;[\rho, \theta])',  'I(\Thetaexp; \Theta)'};
%     MIForce = NaN(length(WINDOW), length(OFFSET), length(MIFopt));
%     for mm=1:length(MIFopt)
%         opts.MIForce = MIFopt{mm};
%         [dirName, fileName] = file_opts_REPOSITORY(opts, infotyp);
%         load(fullfile(dirName, fileName));
%         MIForce(:,:,mm) = squeeze(I(uu,:,:,ii));
%     end;

    PerfLabel = {'rate of convergences', 'number of steps to convergence'};
    nbconv = NaN(length(WINDOW), length(OFFSET));
    nbstp = NaN(length(WINDOW), length(OFFSET));

%     opts.cal='cal1';
    [dirName, fileName] = file_opts_REPOSITORY(opts, 'sim');
    load(fullfile(dirName, fileName));
    
    for kk=1:length(OFFSET)
        for jj=1:length(WINDOW)
            conv = squeeze(sim.Converge(uu,jj,kk,ii,:));
            nbconv(jj,kk) =round(100*sum(~isnan(conv(:)))/length(conv(:)));
            nbstp(jj,kk) =round(mean(conv(~isnan(conv))));
        end
    end;
    
    %% -------------------------
    % PLOT CALIBRATION
    % -------------------------
    
   
    %figure; set(gcf,'pos',[263         103        1194         739]);
    
    Forces=squeeze(cal.ForceTest(uu,jj,kk,ii,:,:,:));
    RecPoint=double(squeeze(cal.RecPoint(uu,jj,kk,ii,:,:)));
    RecF=squeeze(cal.RecForce(uu,jj,kk,ii,:,:));
    
    TRI = delaunay(double(RecPoint(:,1)),double(RecPoint(:,2)));
    ax=Xrange(1):.2:Xrange(2);
    sensfield=nan(length(ax));
    for x = 1:length(ax)
        for y = 1:length(ax)
            nearest = dsearch(RecPoint(:,1),RecPoint(:,2),TRI,ax(x),ax(y));
            sensfield(y,x)=nearest;
        end
    end
%%
    figure; set(gcf,'pos',[560   346   768   598])
    imagesc(ax,ax,sensfield)
    set(gca,'ydir','normal');
    hold on;
    plot(RecPoint(:,1),RecPoint(:,2),'o','MarkerEdgeColor','w','MarkerFaceColor','w','MarkerSize',5)
    for ss=1:nstims,
        text(RecPoint(ss,1),RecPoint(ss,2),['' num2str(ss)],'VerticalAlignment', 'bottom','fontsize',12,'fontweight','bold')
    end;
    
            Pos=squeeze(sim.State(uu,jj,kk,ii,1:20,:,1:2));
%         SimForces=squeeze(sim.Force(uu,jj,kk,ii,1:20,:,:));
    plotTrajectories(Pos,[]); %?????
    
    title('simulation','fontsize',16,'fontweight','bold')
%     ptmp=get(hs,'pos'); ptmp(2)=ptmp(2)-ptmp(4)/2; set(hs,'pos',ptmp);
    set(gca,'xtick',[],'ytick',[]); axis(max(Xrange)*[-1 1 -1 1])
    
        % display performances
    txtdip{1}=[PerfLabel{1} '= ' num2str(nbconv(jj,kk)) '%'];
    txtdip{2}=[PerfLabel{2} '= ' num2str(nbstp(jj,kk))];
%     for mi=1:3
% %         txtdip{mi+2}= [MIForceLabels{mi} ' = ' num2str(squeeze(MIForce(jj,kk,mi))) ' bits'];
%         txtdip{mi+2}= sprintf('%s = %0.2f bits', MIForceLabels{mi}, squeeze(MIForce(jj,kk,mi)));
%     end;
    hb=annotation('textbox',[.5 .2 .1 .1]);
    set(hb,'string',txtdip,'fontsize',12,'fontweight','bold')
    brighten(.5)
    
    fname=['sim_' opts.set '_' opts.algo '.svg'];
% plot2svg(['/media/TOSHDATA_/BMIproject_svn/documentation/reports/Apr2012/' fname])
%%    
    % for each stimulus
    figure;
    set(gcf,'pos',[271         105        1085         827])
    ncol=ceil(sqrt(nstims));
    nrow=ceil(nstims/ncol);
    for ss=1:nstims,
        hs(ss)=subplot(nrow,ncol,ss);
        
        F=squeeze(Forces(1:ntrials(ss),ss,:));
        Fm=mean(F,1);
%         a=angle(F(:,1)+1i*F(:,2));
%         angbins=-pi:pi/6:pi;
%         [n bin]=histc(a,angbins);
%         Fbinsum=nan(length(n),2);
%         for bb=1:length(n);
%             Fbinsum(bb,:)=(length(n)/ntrials(ss))*sum(F(bin==bb,:),1);
%         end;
        
        %             hcomp=compass(Fbinsum(:,1),Fbinsum(:,2),'k');
        hcomp=compass(F(:,1),F(:,2),'k');
        %             for hh=1:length(hcomp),
        %                 set(hcomp(hh),'linewidth',2);
        %             end;
        hold on;
        GraphicGain=1; % to make the average force vectors visible
        p = arrw([0 0]', GraphicGain*[RecF(ss,1), RecF(ss,2)]');
        plot(p(1,:), p(2,:), 'b','linewidth',3);
        p = arrw([0 0]', GraphicGain*[Fm(1), Fm(2)]');
        plot(p(1,:), p(2,:), 'r','linewidth',3);
        
        title(['stim ' num2str(ss)],'fontsize',15,'fontweight','bold')
    end;
    
    for ss=1:nstims
        ptmp=get(hs(ss),'pos'); 
        ptmp(2)=ptmp(2)-0.05; 
        ptmp(3:4)=1.2*ptmp(3:4); 
        set(hs(ss),'pos',ptmp);
    end;
    
    [~,h]=suplabel(['set ' num2str(ff) ': ' strrep(opts.set,'_','-') '. offset=' num2str(OFFSET(kk)) 'ms. ' 'bin=' num2str(BIN(ii)) 'ms ' '. window=' num2str(WINDOW(jj)) 'ms']  ,'t',[.08 .13 .84 .84]);
    set(h,'FontSize',15)
        
    if savefigs
        set(gcf,'color',[1 1 1])
        fname=['calallF_' opts.set '_' opts.algo '_win' num2str(WINDOW(jj)) 'ms' '_off' num2str(OFFSET(kk)) 'ms' '_bin' num2str(BIN(ii)) 'ms'];
        export_fig(fullfile(dirs.plotNIPS,[fname '.eps']));
        export_fig(fullfile(dirs.plotNIPS,[fname '.png']));
        close;
        
    end;
end;