% Plot Force vectors from the test set at the location corresponding to the
% stimulus that elicited them

clear; clc;
dirs = dir_opts_REPOSITORY;
savefigs=0;

calz={'cal30','cal40','cal50','cal60','cal70'};

getsetList;
ff = 30;
% ffs=[23 28 29 30 31];

opts.rec = 'rec0';
uu = 1; % set of SUs
ii = 1; % bin

opts.algo = 'algo1';
opts.dynSys = 'dynSys1';

% -------------------------
% load sampling parameters
% -------------------------
rec_opts = rec_opts_REPOSITORY(opts.rec);
BIN = rec_opts.bin;
WINDOW = rec_opts.window;
OFFSET = rec_opts.offset;

% -------------------------
% load dynamical system parameters
% -------------------------
dynSys_opts = dynSys_opts_REPOSITORY(opts.dynSys);
Stiffness = dynSys_opts.stiffness;
Mass = dynSys_opts.mass;
Damping = dynSys_opts.damping;
Xrange = dynSys_opts.Xrange;
Yrange = dynSys_opts.Yrange;
Radius = dynSys_opts.radius;
Zero = dynSys_opts.zero;
% -------------------------

% -------------------------
% select data set
% -------------------------
opts.set = setList{ff};

for cc=1:length(calz)
    opts.cal=calz{cc};
    
    % -------------------------
    % load calibration file
    % -------------------------
    [dirName, fileName] = file_opts_REPOSITORY(opts, 'cal');
    load(fullfile(dirName, fileName));
    ntrials=cal.testntrials
    
    
    % -------------------------
    % PLOT CALIBRATION
    % -------------------------
    
    jj = 1; % window
    kk = 1; % offset
    jj = 1; % window
    
    figure; set(gcf,'pos',[263         103        1194         739]);
    
    Forces=squeeze(cal.ForceTest(uu,jj,kk,ii,:,:,:));
    RecPts=double(squeeze(cal.RecPoint(uu,jj,kk,ii,:,:)))';
    RecF=squeeze(cal.RecForce(uu,jj,kk,ii,:,:));
    
    %         subplot(2,3,1);
    %         plotCalibration(RecPts,RecF,Forces,ntrials);
    
    hs=subplot(2,3,1);
    colorCode = ['r' 'c' 'g' 'b']';
    % colorCode = [0 0 1; 1 0 0; .1 .5 .1; 0.7 0.6 0];
    hold on;
    TRI = delaunay(RecPts(1,:),RecPts(2,:));
    for x = Xrange(1):0.4:Xrange(2)
        for y = Yrange(1):0.4:Yrange(2)
            nearest = dsearch(RecPts(1,:),RecPts(2,:),TRI,x,y);
            plot(x,y,'s','LineWidth',1,'MarkerEdgeColor',colorCode(nearest,:),'MarkerFaceColor',colorCode(nearest,:),'MarkerSize',5);
        end
    end
    plot(RecPts(1,:),RecPts(2,:),'o','MarkerEdgeColor','w','MarkerFaceColor','w','MarkerSize',5)
    for ss=1:4,
        text(RecPts(1,ss),RecPts(2,ss),['stim ' num2str(ss)],'VerticalAlignment', 'bottom')
    end;
    title('sensory regions','fontsize',12,'fontweight','bold')
    ptmp=get(hs,'pos'); ptmp(2)=ptmp(2)-ptmp(4)/2; set(hs,'pos',ptmp);
    
    % for each stimulus
    pidx=[2 3 5 6];
    for ss=1:4,
        hs(ss)=subplot(2,3,pidx(ss));
        
        F=squeeze(Forces(1:ntrials(ss),ss,:));
        Fm=mean(F,1);
        a=angle(F(:,1)+1i*F(:,2));
        angbins=-pi:pi/6:pi;
        [n bin]=histc(a,angbins);
        Fbinsum=nan(length(n),2);
        for bb=1:length(n);
            Fbinsum(bb,:)=(length(n)/ntrials(ss))*sum(F(bin==bb,:),1);
        end;
        
        %             hcomp=compass(Fbinsum(:,1),Fbinsum(:,2),'k');
        hcomp=compass(F(:,1),F(:,2),'k');
        for hh=1:length(hcomp),
            set(hcomp(hh),'linewidth',1.5);
        end;
        hold on;
        GraphicGain=2; % to make the average force vectors visible
        p = arrw([0 0]', GraphicGain*[RecF(ss,1), RecF(ss,2)]');
        plot(p(1,:), p(2,:), 'b','linewidth',3);
        p = arrw([0 0]', GraphicGain*[Fm(1), Fm(2)]');
        plot(p(1,:), p(2,:), 'r','linewidth',3);
        
        title(['stim ' num2str(ss)],'fontsize',12,'fontweight','bold')
    end;
    
    for ss=[1 2],
        ptmp=get(hs(ss),'pos'); ptmp(2)=ptmp(2)-0.05; set(hs(ss),'pos',ptmp);
    end;
    
    [ax,h]=suplabel(['set ' num2str(ff) ': ' strrep(opts.set,'_','-') '. offset=' num2str(OFFSET(kk)) 'ms. ' 'bin=' num2str(BIN(ii)) 'ms ' '. window=' num2str(WINDOW(jj)) 'ms']  ,'t',[.08 .13 .84 .84]);
    set(h,'FontSize',15)
    
    
    if savefigs
        set(gcf,'color',[1 1 1])
        fname=['calallF_' opts.set '_win' num2str(WINDOW(jj)) 'ms' '_off' num2str(OFFSET(kk)) 'ms' '_bin' num2str(BIN(ii)) 'ms'];
        export_fig(fullfile(dirs.plotcalib,[fname '.eps']));
        saveas(gcf,fullfile(dirs.plotcalib,fname),'fig');
        close;
    end;
end;