% Plot Force vectors from the test set at the location corresponding to the
% stimulus that elicited them

clear; clc;
dirs = dir_opts_REPOSITORY;
savefigs=0;

getsetList; 
for ff = 39 %59:length(setList)
% ffs=[23 20 29 30 31];
% w{23}=[3];
% w{20}=[4 6 8];
% w{29}=[7];
% w{30}=[3 5 8];
% w{31}=[4];
% getSimulatedSetList; ff=2;

opts.rec = 'rec0'; 
% opts.rec = 'rec0bin';
% opts.rec = 'rec0offwin';


uu = 1; % set of SUs
ii = 1; % bin

opts.cal='cal100';
% opts.cal='cal1';
opts.algo = 'algo1';
opts.dynSys = 'dynSys1';
opts.sim = 'sim1';

% -------------------------
% load sampling parameters
% -------------------------
rec_opts = rec_opts_REPOSITORY(opts.rec);
BIN = rec_opts.bin;
WINDOW = rec_opts.window;
OFFSET = rec_opts.offset;

% -------------------------
% load dynamical system parameters
% -------------------------
dynSys_opts = dynSys_opts_REPOSITORY(opts.dynSys);
Stiffness = dynSys_opts.stiffness;
Mass = dynSys_opts.mass;
Damping = dynSys_opts.damping;
Xrange = dynSys_opts.Xrange;
Yrange = dynSys_opts.Yrange;
Radius = dynSys_opts.radius;
Zero = dynSys_opts.zero;
% -------------------------

% for ff=ffs
% -------------------------
% select data set
% -------------------------
opts.set = setList{ff};

% -------------------------
% load calibration file
% -------------------------
[dirName, fileName] = file_opts_REPOSITORY(opts, 'cal');
load(fullfile(dirName, fileName));
ntrials=cal.testntrials;


% -------------------------
% load simulation performances to display on figure
% -------------------------
MIFopt = {'FxFy0','RT0','AC0'}; infotyp='infoForceFromTraj';
% MIFopt = {'FxFy1','RT1','AC1'}; infotyp='infoForce';
MIForceLabels = {'I(S; [Fx,Fy])', 'I(S;[\rho, \theta])',  'I(\Thetaexp; \Theta)'};
MIForce = NaN(length(WINDOW), length(OFFSET), length(MIFopt));
for mm=1:length(MIFopt)
    opts.MIForce = MIFopt{mm};
    [dirName, fileName] = file_opts_REPOSITORY(opts, infotyp);
    load(fullfile(dirName, fileName));
    MIForce(:,:,mm) = squeeze(I(uu,:,:,ii));
end;
    
PerfLabel = 'corrected rate of convergences';
Perf = NaN(length(WINDOW), length(OFFSET));
opts.cal='cal100rand';
% opts.cal='calrand1';
[dirName, fileName] = file_opts_REPOSITORY(opts, 'sim');
load(fullfile(dirName, fileName));
simrand=sim;
opts.cal='cal100';
% opts.cal='cal1';
[dirName, fileName] = file_opts_REPOSITORY(opts, 'sim');
load(fullfile(dirName, fileName));

for kk=1:length(OFFSET)
    for jj=1:length(WINDOW)
    conv = squeeze(sim.Converge(uu,jj,kk,ii,:));
    nbconv =round(100*sum(~isnan(conv(:)))/length(conv(:)));
    convrand = squeeze(simrand.Converge(uu,jj,kk,ii,:));
    nbconvrand =round(100*sum(~isnan(convrand(:)))/length(convrand(:)));
    Perf(jj,kk)=nbconv-nbconvrand;
    end
end;

%% -------------------------
% PLOT CALIBRATION
% -------------------------

% jj = 8; % window
% kk = 1; % offset

for kk=1
    for jj=1 %w{ff} 
        figure; set(gcf,'pos',[263         103        1194         739]);
        
        Forces=squeeze(cal.ForceTest(uu,jj,kk,ii,:,:,:));
        RecPts=double(squeeze(cal.RecPoint(uu,jj,kk,ii,:,:)))';
        RecF=squeeze(cal.RecForce(uu,jj,kk,ii,:,:));
        
%         subplot(2,3,1);
%         plotCalibration(RecPts,RecF,Forces,ntrials);
        
        hs=subplot(2,3,1);
        plot_SensoryRegions(RecPts,.1)
        title('sensory regions','fontsize',20,'fontweight','bold')
        ptmp=get(hs,'pos'); ptmp(2)=ptmp(2)-ptmp(4)/2; set(hs,'pos',ptmp);

        % for each stimulus
        pidx=[2 3 5 6];
        for ss=1:size(RecPts,2),
            hs(ss)=subplot(2,3,pidx(ss));
            
            F=squeeze(Forces(1:ntrials(ss),ss,:));
            Fm=mean(F,1);
            a=angle(F(:,1)+1i*F(:,2));
            angbins=-pi:pi/6:pi;
            [n bin]=histc(a,angbins);
            Fbinsum=nan(length(n),2);
            for bb=1:length(n);
                Fbinsum(bb,:)=(length(n)/ntrials(ss))*sum(F(bin==bb,:),1);
            end;
            
%             hcomp=compass(Fbinsum(:,1),Fbinsum(:,2),'k');
            hcomp=compass(F(:,1),F(:,2),'k');
            for hh=1:length(hcomp),
                set(hcomp(hh),'linewidth',1);
            end;
            hold on;
            GraphicGain=2; % to make the average force vectors visible
            p = arrw([0 0]', GraphicGain*[RecF(ss,1), RecF(ss,2)]');
            plot(p(1,:), p(2,:), 'b','linewidth',3);
            p = arrw([0 0]', GraphicGain*[Fm(1), Fm(2)]');
            plot(p(1,:), p(2,:), 'r','linewidth',3);
            
            title(['stim ' num2str(ss)],'fontsize',20,'fontweight','bold')
        end;
        
        for ss=[1 2],
            ptmp=get(hs(ss),'pos'); ptmp(2)=ptmp(2)-0.05; set(hs(ss),'pos',ptmp);
        end;
        
        [ax,h]=suplabel(['set ' num2str(ff) ': ' strrep(opts.set,'_','-') '. offset=' num2str(OFFSET(kk)) 'ms. ' 'bin=' num2str(BIN(ii)) 'ms ' '. window=' num2str(WINDOW(jj)) 'ms']  ,'t',[.08 .13 .84 .84]);
        set(h,'FontSize',15)
               
         % display performances
         txtdip{1}=[PerfLabel '= ' num2str(Perf(jj,kk)) '%'];
         for mi=1:3
             txtdip{mi+1}= [MIForceLabels{mi} ' = ' num2str(squeeze(MIForce(jj,kk,mi))) ' bits'];
         end;
         hb=annotation('textbox',[.1 .18 .1 .1]);
         set(hb,'string',txtdip,'fontsize',15)
         
         if savefigs
            set(gcf,'color',[1 1 1])
            fname=['calallF_' opts.set '_win' num2str(WINDOW(jj)) 'ms' '_off' num2str(OFFSET(kk)) 'ms' '_bin' num2str(BIN(ii)) 'ms'];
%             fname=['calbinF_' opts.set '_win' num2str(WINDOW(jj)) 'ms' '_off' num2str(OFFSET(kk)) 'ms' '_bin' num2str(BIN(ii)) 'ms'];
            export_fig(fullfile(dirs.plotcalib,[fname '.eps']));
            saveas(gcf,fullfile(dirs.plotcalib,fname),'fig');
            
%             fname=['SALAMANCA_calallF_' opts.set '_win' num2str(WINDOW(jj)) 'ms' '_off' num2str(OFFSET(kk)) 'ms' '_bin' num2str(BIN(ii)) 'ms'];
%             plot2svg([fullfile(dirs.plotvar,fname) '.svg'],gcf)

            close;
        end;
    end;
end;
end;