% Plot Force vectors from the test set at the location corresponding to the
% stimulus that elicited them

clear; clc;

getsetList; ff = 35;
% getSimulatedSetList; ff=2;

opts.rec = 'rec4win';
opts.cal='cal100';
opts.algo = 'algo1';
opts.dynSys = 'dynSys1';

% -------------------------
% load sampling parameters
% -------------------------
rec_opts = rec_opts_REPOSITORY(opts.rec);
BIN = rec_opts.bin;
WINDOW = rec_opts.window;
OFFSET = rec_opts.offset;

% -------------------------
% load dynamical system parameters
% -------------------------
dynSys_opts = dynSys_opts_REPOSITORY(opts.dynSys);
Stiffness = dynSys_opts.stiffness;
Mass = dynSys_opts.mass;
Damping = dynSys_opts.damping;
Xrange = dynSys_opts.Xrange;
Yrange = dynSys_opts.Yrange;
Radius = dynSys_opts.radius;
Zero = dynSys_opts.zero;
% -------------------------


% -------------------------
% select data set
% -------------------------
opts.set = setList{ff};

% -------------------------
% load calibration file
% -------------------------
[dirName, fileName] = file_opts_REPOSITORY(opts, 'cal');
load(fullfile(dirName, fileName));
ntrials=cal.testntrials;

% -------------------------
% PLOT CALIBRATION
% -------------------------
uu = 1; % set of SUs
ii = 1; % bin
jj = 4; % window
kk = 1; % offset

figure;

RecPts=double(squeeze(cal.RecPoint(uu,jj,kk,ii,:,:)))';
RecF=squeeze(cal.RecForce(uu,jj,kk,ii,:,:))';
TRI = delaunay(RecPts(1,:),RecPts(2,:));
[gainF, maxF] = SetForceGraphics(Xrange, Yrange, Stiffness);

plot_FragmentedField(Xrange, Yrange, RecPts, RecF, TRI, gainF, maxF);

title([strrep(opts.set,'_','-') '. window=' num2str(WINDOW(jj)) 'ms' '. offset=' num2str(OFFSET(kk)) 'ms. bin=' num2str(BIN(ii)) 'ms '],'FontSize',15);
