% Plot Force vectors from the test set at the location corresponding to the
% stimulus that elicited them

clear; clc;
dirs = dir_opts_REPOSITORY;

getsetList; ff = 35;
% getSimulatedSetList; ff=2;

opts.rec = 'rec4win';
opts.cal='cal100';
opts.algo = 'algo1';
opts.dynSys = 'dynSys1';

% -------------------------
% load sampling parameters
% -------------------------
rec_opts = rec_opts_REPOSITORY(opts.rec);
BIN = rec_opts.bin;
WINDOW = rec_opts.window;
OFFSET = rec_opts.offset;

% -------------------------
% load dynamical system parameters
% -------------------------
dynSys_opts = dynSys_opts_REPOSITORY(opts.dynSys);
Stiffness = dynSys_opts.stiffness;
Mass = dynSys_opts.mass;
Damping = dynSys_opts.damping;
Xrange = dynSys_opts.Xrange;
Yrange = dynSys_opts.Yrange;
Radius = dynSys_opts.radius;
Zero = dynSys_opts.zero;
% -------------------------


% -------------------------
% select data set
% -------------------------
opts.set = setList{ff};

% -------------------------
% load calibration file
% -------------------------
[dirName, fileName] = file_opts_REPOSITORY(opts, 'cal');
load(fullfile(dirName, fileName));
ntrials=cal.testntrials;

% -------------------------
% PLOT resulting field
% -------------------------
uu = 1; % set of SUs
ii = 1; % bin
jj = 4; % window
kk = 1; % offset


RecPts=double(squeeze(cal.RecPoint(uu,jj,kk,ii,:,:)))';
RecF=squeeze(cal.RecForce(uu,jj,kk,ii,:,:))';
Forces=squeeze(cal.ForceTest(uu,jj,kk,ii,:,:,:));

TRI = delaunay(RecPts(1,:),RecPts(2,:));
[gainF, maxF] = SetForceGraphics(Xrange, Yrange, Stiffness);

figure;

for zz=1:100
    clf; 
    %     plot_FragmentedField(Xrange, Yrange, RecPts, RecF, TRI, gainF, maxF);
    plot_InterpolatedField(Xrange, Yrange, RecPts, Forces, ntrials,TRI, gainF, maxF)
    
    axis(14*[-1 1 -1 1]); set(gca,'visible','off'); set(gcf,'color',[1 1 1]);
%     title([strrep(opts.set,'_','-') '. bin=' num2str(BIN(ii)) 'ms' '. window=' num2str(WINDOW(jj)) 'ms' '. offset=' num2str(OFFSET(kk)) 'ms ']);
   
    reply = input('Do you want to save it? y/n [n]: ', 's');
    if isempty(reply)
        reply = 'n';
    end

    if strcmp(reply,'y')
        fname=['InterpField_' opts.set '_win' num2str(WINDOW(jj)) 'ms' '_off' num2str(OFFSET(kk)) 'ms' '_bin' num2str(BIN(ii)) 'ms_' num2str(zz)];
        export_fig(fullfile(dirs.plotInterpfield,[fname '.eps']));
        saveas(gcf,fullfile(dirs.plotInterpfield,fname),'fig');
    end;
end;


%%
% -------------------------
% PLOT resulting field
% -------------------------
uu = 1; % set of SUs
ii = 2; % bin
jj = 1; % window
kk = 1; % offset

RecPts=double(squeeze(cal.RecPoint(uu,jj,kk,ii,:,:)))';
RecF=squeeze(cal.RecForce(uu,jj,kk,ii,:,:))';
Forces=squeeze(cal.ForceTest(uu,jj,kk,ii,:,:,:));

TRI = delaunay(RecPts(1,:),RecPts(2,:));
[gainF, maxF] = SetForceGraphics(Xrange, Yrange, Stiffness);

figure;
subplot(1,2,1)
plot_FragmentedField(Xrange, Yrange, RecPts, RecF, TRI, gainF, maxF);
xlim(Xrange); ylim(Yrange);

subplot(1,2,2)
plot_InterpolatedField(Xrange, Yrange, RecPts, Forces, ntrials,TRI, gainF, maxF)
xlim(Xrange); ylim(Yrange);

[ax,h]=suplabel([num2str(ff) ': ' opts.set '. window=' num2str(WINDOW(jj)) 'ms' '. offset=' num2str(OFFSET(kk)) 'ms ' '. bin=' num2str(BIN(ii)) 'ms ']  ,'t');
set(h,'FontSize',15,'pos',[.5 .9 1])