
setrootdir;
getsetList;

opts.rec = 'rec0bin';
opts.cal='cal1';
opts.algo = 'algo1';
opts.dynSys = 'dynSys1';
opts.sim = 'sim1';

% -------------------------
% load sampling parameters
% -------------------------
rec_opts = rec_opts_REPOSITORY(opts.rec);
BIN = rec_opts.bin;
WINDOW = rec_opts.window;
OFFSET = rec_opts.offset;
% -------------------------

% ff = 1; % data set
uu = 1; % set of units
% ii = 1; % bin
jj = 1; % window
kk = 1; % offset

calz={'cal1','calrand1'};
PerfLabels = {'percentage of convergences','mean nb of steps to convergence','mean nb of steps'};
Perf = NaN(length(setList), length(BIN), length(PerfLabels));
PerfShuff = NaN(length(setList), length(BIN), length(PerfLabels));

for ff=1:length(setList)
    
    % -------------------------
    % select data set
    % -------------------------
    opts.set = setList{ff};
    
    for cc=1:length(calz)
        % -------------------------
        % load simulation file
        % -------------------------
        opts.cal=calz{cc};
        [dirName, fileName] = file_opts_REPOSITORY(opts, 'sim');
        load(fullfile(dirName, fileName));
        
        for ii=1:length(BIN),
            
            % -------------------------
            % evaluate performance
            % -------------------------
            Converge=squeeze(sim.Converge(uu,jj,kk,ii,:));
            
            % percentage of convergences
            nbconv=round(100*sum(~isnan(Converge))/length(Converge));
            
            % mean number of steps to convergence (when it does)
            nbstp_conv=round(nanmean(Converge(~isnan(Converge))));
            
            % mean number of steps (set it to 100 when it didnt converge)
            nbstptmp=Converge;
            nbstptmp(isnan(nbstptmp))=100;
            nbstp_all=mean(nbstptmp);
            
            % -------------------------
            % store results
            % -------------------------
            switch opts.cal
                case 'cal1'
                    Perf(ff,ii,1)=nbconv;
                    Perf(ff,ii,2)=nbstp_conv;
                    Perf(ff,ii,3)=nbstp_all;
                    
                case 'calrand1'
                    PerfShuff(ff,ii,1)=nbconv;
                    PerfShuff(ff,ii,2)=nbstp_conv;
                    PerfShuff(ff,ii,3)=nbstp_all;
            end;
        end;
    end;
end;


%% correct for the convergences occuring by chance
% NOTE: less chance of converging for smaller force vectors (small bins
% with algo 1)

PERF=Perf;

% we substract the percentage of convergences occuring by chance after
% shuffling of data across trials and stim
PERF(:,:,1)=PERF(:,:,1)-PerfShuff(:,:,1);
PerfLabels{1}=[PerfLabels{1} ' (chance level substracted)'];

%% -------------------------
% plot performance
% -------------------------

figure;
set(gcf,'pos',[76         298        1590         580])

for pp=1:length(PerfLabels)
    
    prf=squeeze(PERF(:,:,pp));
    
    h(1,pp)=subplot(3,3,[pp 3+pp]);
    imagescnan(prf)
    set(gca,'xtick',1:numel(BIN),'xticklabel',num2str(BIN'))
    ylabel('data set');
    colorbar;
    title(PerfLabels{pp})
    
    h(2,pp)=subplot(3,3,6+pp);
    errorbar(nanmean(prf,1),nanstd(prf,[],1)/sqrt(length(BIN)))
    set(gca,'xtick',1:numel(BIN),'xticklabel',num2str(BIN'))
    xlabel('bin (ms)');
    
end;

% beautify
for ii=1:3,
    p1=get(h(1,ii),'pos');
    p2=get(h(2,ii),'pos');
    p2(3)=p1(3);
    set(h(2,ii),'pos',p2)
end;

set(h(2,1),'ylim',[-10 60])
set(h(2,2),'ylim',[20 70])
set(h(2,3),'ylim',[50 100])