
setrootdir;
getsetList;

savefigs=0;

opts.rec = 'rec0offwin';
opts.cal='cal1';
opts.algo = 'algo1';
opts.dynSys = 'dynSys1';
opts.sim = 'sim1';

% -------------------------
% load sampling parameters
% -------------------------
rec_opts = rec_opts_REPOSITORY(opts.rec);
BIN = rec_opts.bin;
WINDOW = rec_opts.window;
OFFSET = rec_opts.offset;
% -------------------------

% ff = 1; % data set
uu = 1; % set of units
ii = 1; % bin
% jj = 1; % window
% kk = 1; % offset

calz={'cal1','calrand1'};
PerfLabels = {'percentage of convergences','mean 1/nb of steps to convergence','mean nb of steps'};
Perf = NaN(length(setList), length(WINDOW),length(OFFSET), length(PerfLabels));
PerfShuff = NaN(length(setList), length(WINDOW),length(OFFSET), length(PerfLabels));

for ff=1:34 %length(setList)
    
    % -------------------------
    % select data set
    % -------------------------
    opts.set = setList{ff};
    
    for cc=1:length(calz)
        % -------------------------
        % load simulation file
        % -------------------------
        opts.cal=calz{cc};
        [dirName, fileName] = file_opts_REPOSITORY(opts, 'sim');
        load(fullfile(dirName, fileName));
        
        for jj=1:length(WINDOW),
            for kk=1:length(OFFSET),
                
                % -------------------------
                % evaluate performance
                % -------------------------
                Converge=squeeze(sim.Converge(uu,jj,kk,ii,:));
                
                % percentage of convergences
                nbconv=round(100*sum(~isnan(Converge))/length(Converge));
                
                % mean 1/number of steps to convergence (when it does)
                nbstp_conv=nanmean(1./Converge(~isnan(Converge)));
                
                % mean number of steps (set it to 100 when it didnt converge)
                nbstptmp=Converge;
                nbstptmp(isnan(nbstptmp))=100;
                nbstp_all=mean(nbstptmp);
                
                % -------------------------
                % store results
                % -------------------------
                switch opts.cal
                    case 'cal1'
                        Perf(ff,jj,kk,1)=nbconv;
                        Perf(ff,jj,kk,2)=nbstp_conv;
                        Perf(ff,jj,kk,3)=nbstp_all;
                        
                    case 'calrand1'
                        PerfShuff(ff,jj,kk,1)=nbconv;
                        PerfShuff(ff,jj,kk,2)=nbstp_conv;
                        PerfShuff(ff,jj,kk,3)=nbstp_all;
                end;
            end;
        end;
    end;
end;

% correct for the convergences occuring by chance
% NOTE: less chance of converging for smaller force vectors (small bins
% with algo 1)

PERF=Perf;

% we substract the percentage of convergences occuring by chance after
% shuffling of data across trials and stim
PERF(:,:,:,1)=PERF(:,:,:,1)-PerfShuff(:,:,:,1);
PerfLabels{1}=[PerfLabels{1} ' (chance level substracted)'];

%% get rid of bad data

% rmcond='all'; idxrem=[];
% rmcond='maxCR50'; idxrem=[2     5    10    17    18];             
rmcond='maxCR60'; idxrem=[2     5    10    11    12    15    16    17    18    27];   
% rmcond='maxMIFxFy04'; idxrem=[2     3     5     6    18];
% rmcond='maxMIteta01'; idxrem=[2     3     5    10    11    12    14   18]; 

idxkeep=setdiff(1:length(setList),idxrem);

% -------------------------
% plot performance
% -------------------------

figure;
set(gcf,'pos',[234   442   961   421])
cxis=[0 50; 0.02 0.04];
for pp=1:length(PerfLabels)-1
    
    prf=squeeze(nanmean(PERF(idxkeep,:,:,pp),1));
    
    h(pp)=subplot(1,2,pp);
    imagescnan(prf)
    set(gca,'xtick',1:numel(OFFSET),'xticklabel',num2str(OFFSET'),'ytick',1:numel(WINDOW),'yticklabel',num2str(WINDOW'),'ydir','normal')
    xlabel('offset [ms]');
    ylabel('window duration [ms]');
    colorbar;
%     caxis(cxis(pp,:))
caxis([0 max(prf(:))])
    title(PerfLabels{pp})
end;

if savefigs
    set(gcf,'color',[1 1 1])
    fname=['CRwinoffset_' opts.algo '_' opts.dynSys '_' opts.sim '_' rmcond];
    dirs = dir_opts_REPOSITORY;
    export_fig(fullfile(dirs.plotPerfMI,[fname '.eps']));
    saveas(gcf,fullfile(dirs.plotPerfMI,fname),'fig');
    close;
end;