% Plot Force vectors from the test set at the location corresponding to the
% stimulus that elicited them

clear; clc;
dirs = dir_opts_REPOSITORY;
savefigs=0;

% getsetList;
getSimMixSetList;
gamma=[0 0.25 0.50 0.75 1];
visc=[13 29 25 31 37];

dynSys={'dynSys_damp13','dynSys_damp19','dynSys_damp25','dynSys_damp31','dynSys_damp37'};

cvars = NaN(length(setList),4);

uu = 1; % set of SUs
ii = 1; % bin
jj = 1; % window
kk = 1; % offset

opts.rec = 'recsimmix';
opts.cal='cal1';
opts.algo = 'algo1';
% opts.sim = 'sim2';

dd=1; %calibration yields the same results irrespespective of the viscosity
for ff = 1:length(setList)
    opts.set = setList{ff};
    opts.dynSys=dynSys{dd};
    [dirName, fileName] = file_opts_REPOSITORY(opts, 'cal');
    load(fullfile(dirName, fileName));
    F = squeeze(cal.ForceTest(uu,jj,kk,ii,:,:,:));
    
    for ss=1:4,
        ftmp=squeeze(F(:,ss,:));
        angs=angle(ftmp(:,1)+1i*ftmp(:,2));
        cvars(ff,ss)=1-abs(mean(cos(angs)+1i*sin(angs)));
    end;
end;

%% Circular Variance (imagesc)

figure;
imagesc(cvars);
colorbar;
set(gca,'ydir','normal','ytick',1:length(gamma),'yticklabel',num2str(gamma'),'xtick',1:4,'xticklabel',num2str((1:4)'));
ylabel('gamma'); xlabel('stimulus');
title('Circular Variance');

cmap=gray;
colormap(cmap);
caxis([0 1])
brighten(0.2);

if savefigs
    set(gcf,'color',[1 1 1]);
    fname='cvar_image';
    export_fig(fullfile(dirs.plotsimmix,[fname '.eps']));
end;

%% Circular Variance (bars)

figure;
set(gcf,'pos',[560   375   964   569])
for ss=1:4
    h(ss)=subplot(2,2,ss);
    bar(cvars(:,ss));
    ylim([0 1]);
    title(['stimulus ' num2str(ss)])
end;
colormap gray

set(get(h(1),'ylabel'),'string','CVAR')
set(get(h(3),'ylabel'),'string','CVAR')
set(get(h(3),'xlabel'),'string','gamma')
set(get(h(4),'xlabel'),'string','gamma')
set(h(1),'xtick',[]);
set(h(2),'xtick',[]);
set(h(3),'xtick',1:length(gamma),'xticklabel',num2str(gamma'))
set(h(4),'xtick',1:length(gamma),'xticklabel',num2str(gamma'))

if savefigs
    set(gcf,'color',[1 1 1]);
    fname='cvar_bars';
    export_fig(fullfile(dirs.plotsimmix,[fname '.eps']));
end;

%% Circular Variance (bars avg)

figure;
barwitherr(std(cvars,0,2)/sqrt(5),mean(cvars,2),'k')
ylim([0 1]);
colormap gray
ylabel('CVAR'); 
xlabel('gamma')
set(gca,'xtick',1:length(gamma),'xticklabel',num2str(gamma'))

if savefigs
    set(gcf,'color',[1 1 1]);
    fname='cvar_barsavg';
    export_fig(fullfile(dirs.plotsimmix,[fname '.eps']));
end;
