% Plot Force vectors from the test set at the location corresponding to the
% stimulus that elicited them

clear; clc;
dirs = dir_opts_REPOSITORY;
savefigs=0;

% getsetList;
getSimMixSetList;
gamma=[0 0.25 0.50 0.75 1];
visc=[13 29 25 31 37];

dynSys={'dynSys_damp13','dynSys_damp19','dynSys_damp25','dynSys_damp31','dynSys_damp37'};

PerfLabel = {'rate of convergences', 'number of steps to convergence'};
nbconv = NaN(length(setList),length(dynSys));
nbstp = NaN(length(setList),length(dynSys));
nbstpall = NaN(length(setList),length(dynSys),100);

uu = 1; % set of SUs
ii = 1; % bin
jj = 1; % window
kk = 1; % offset

opts.rec = 'recsimmix';
opts.cal='cal1';
opts.algo = 'algo1';
opts.sim = 'sim2';

for ff = 1:length(setList)
    opts.set = setList{ff};
    for dd=1:length(dynSys)
        opts.dynSys=dynSys{dd};
        [dirName, fileName] = file_opts_REPOSITORY(opts, 'sim');
        load(fullfile(dirName, fileName));
        conv = squeeze(sim.Converge(uu,jj,kk,ii,:));
        nbconv(ff,dd) =round(100*sum(~isnan(conv(:)))/length(conv(:)));
        nbstp(ff,dd) =round(median(conv(~isnan(conv))));
        nbstpall(ff,dd,:) =conv;
    end;
end;

%% convergence rate

figure;
imagesc(nbconv);
colorbar; caxis([0 100])
set(gca,'ydir','normal','ytick',1:length(gamma),'yticklabel',num2str(gamma'),'xtick',1:length(visc),'xticklabel',num2str(visc'));
ylabel('gamma'); xlabel('viscosity (N.s.m^-1)');
title('convergence rate');


% colormap gray;
% brighten(0.5);

if savefigs
    set(gcf,'color',[1 1 1]);
    fname='perf_convrate';
    export_fig(fullfile(dirs.plotsimmix,[fname '.eps']));
    saveas(gcf,fullfile(dirs.plotsimmix,fname),'fig');
end;

%% convergence rate

figure; 
% barwitherr(std(nbconv,0,2)/sqrt(size(nbconv,2)),mean(nbconv,2),'k');
errorbar(mean(nbconv,2),std(nbconv,0,2)/sqrt(size(nbconv,2)),'k','linewidth',2)
set(gca,'xtick',1:length(gamma),'xticklabel',num2str(gamma'));
ylabel('convergence rate'); ylim([0 105]); grid on;
xlabel('gamma');
title('average across viscosity conditions +/-SEM')
if savefigs
    set(gcf,'color',[1 1 1]);
    fname='perf_convrate_meanacrossvisc';
    export_fig(fullfile(dirs.plotsimmix,[fname '.eps']));
end;

%% # steps to convergence

figure;
imagesc(nbstp);
colorbar;
set(gca,'ydir','normal','ytick',1:length(gamma),'yticklabel',num2str(gamma'),'xtick',1:length(visc),'xticklabel',num2str(visc'));
ylabel('gamma'); xlabel('viscosity (N.s.m^{-1})');
title('# steps to convergence');

% colormap gray;
% brighten(0.5);

if savefigs
    set(gcf,'color',[1 1 1]);
    fname='perf_stpconv';
    export_fig(fullfile(dirs.plotsimmix,[fname '.eps']));
    saveas(gcf,fullfile(dirs.plotsimmix,fname),'fig');
end;

%% hist of # steps to convergence

figure;
for ff = 1:length(setList)
    for dd=1:length(dynSys)
        subplot(length(setList),length(dynSys),(ff-1)*length(dynSys)+dd)
        tmp=squeeze(nbstpall(ff,dd,:));
        hist(tmp(~isnan(tmp)));
        xlim([0 100])
    end
end;
