setrootdir;
getsetList; 
savefigs=0;

opts.rec = 'rec0bin';
opts.algo = 'algo1';
opts.dynSys = 'dynSys1';
opts.sim = 'sim1';

% -------------------------
% load sampling parameters
% -------------------------
rec_opts = rec_opts_REPOSITORY(opts.rec);
BIN = rec_opts.bin;
WINDOW = rec_opts.window;
OFFSET = rec_opts.offset;
% -------------------------

MIFopt = {'FxFy0','RT0','AC0'}; infotyp='infoForceFromTraj';
% MIFopt = {'FxFy1','RT1','AC1'}; infotyp='infoForce';

MIForceLabels = {'I(S; [Fx,Fy])', 'I(S;[\rho, \theta])',  'I(\Thetaexp; \Theta)'};
MIForce = NaN(length(setList), length(BIN), length(MIFopt));
MIForceShuff = NaN(length(setList), length(BIN), length(MIFopt));

calz={'cal1','calrand1'};
PerfLabels = {'# of Convergences','1 / # of Steps'};
Perf = NaN(length(setList), length(BIN), length(PerfLabels));
PerfShuff = NaN(length(setList), length(BIN), length(PerfLabels));

uu=1;

% -------------------------
% for each data set
% -------------------------
for ff=1:34
    opts.set = setList{ff};
    disp(opts.set);
    
    % -------------------------
    % load info forces
    % -------------------------
    for mm=1:length(MIFopt)
        opts.cal='cal1';
        opts.MIForce = MIFopt{mm};
        [dirName, fileName] = file_opts_REPOSITORY(opts, infotyp);
        load(fullfile(dirName, fileName));  % load I and Ibtsp
        
        MIForce(ff,:,mm) = squeeze(I(uu,1,1,:));
        MIForceShuff(ff,:,mm) = squeeze(mean(Ibtsp(uu,1,1,:,:),5));
    end;
    
    for cc=1:length(calz)
        % -------------------------
        % load simulation file
        % -------------------------
        opts.cal=calz{cc};
        
        [dirName, fileName] = file_opts_REPOSITORY(opts, 'sim');
        load(fullfile(dirName, fileName));
        
        for ii = 1:numel(BIN)
            % -------------------------
            % evaluate performance
            % -------------------------
            conv = squeeze(sim.Converge(uu,:,:,ii,:));
            
            % percentage of convergences
            nbconv =round(100*sum(~isnan(conv(:)))/length(conv(:)));
            
            % mean number of steps (set it to 100 when it didnt converge)
            conv(find(isnan(conv(:)))) = 100;
            nbstp_all = 1/nanmean(conv(:));
            
            % -------------------------
            % store results
            % -------------------------
            switch opts.cal
                case 'cal1'
                    Perf(ff,ii,1)=nbconv;
                    Perf(ff,ii,2)=nbstp_all;
                    
                case 'calrand1'
                    PerfShuff(ff,ii,1)=nbconv;
                    PerfShuff(ff,ii,2)=nbstp_all;
            end;
        end
    end;
end

%% correct for the convergences occuring by chance
% NOTE: less chance of converging for smaller force vectors (small bins
% with algo 1)
PERF = Perf;
INFO = MIForce;
PERF = PERF - PerfShuff;
INFO = INFO - MIForceShuff;

% get rid of bad data
% rmcond='all'; idxrem=[];
% rmcond='maxCR50'; idxrem=[2     5    10    17    18];             
rmcond='maxCR60'; idxrem=[2     5    10    11    12    15    16    17    18    27];   
% rmcond='maxMIFxFy04'; idxrem=[2     3     5     6    18];
% rmcond='maxMIteta01'; idxrem=[2     3     5    10    11    12    14    18];       

PERF(idxrem,:,:)=[];
INFO(idxrem,:,:)=[];

% -------------------------
% plot boxplots and mean+/-SEM
% -------------------------

figure
set(gcf, 'name', ['window: ' num2str(WINDOW) ' [ms]'],'pos',[73         107        1368         719]);

for pp=1:length(PerfLabels)
    tmp=squeeze(PERF(:,:,pp));        
    hs(1,pp)=subplot(2,3,pp);
    errorbar(1:length(BIN),nanmean(tmp,1),nanstd(tmp,0,1)/sqrt(size(tmp,1)),'k','linewidth',3);
    xlim([1-0.5 length(BIN)+0.5]);
    set(gca,'xtick',1:length(BIN),'xticklabel',num2str(BIN'),'fontname','helvetica','fontsize',14,'fontweight','normal')
    xlabel('\Deltat [ms]','fontname','helvetica','fontsize',16,'fontweight','bold');
    ylabel(PerfLabels{pp},'fontname','helvetica','fontsize',16,'fontweight','bold');
    
    [p(1,pp),table,stats] = anova1(tmp,num2str(BIN'),'off');
    [c m h]=multcompare(stats,'display','off');
    cmpr{1,pp}=c(c(:,3)>0,1:2);
end;

set(hs(1,1),'ylim',[10 60]);
set(hs(1,2),'ylim',[1 10]*1e-3);

for mm=1:length(MIFopt)
    hs(2,mm)=subplot(2,3,3+mm)
    tmp=squeeze(INFO(:,:,mm));
    errorbar(1:length(BIN),nanmean(tmp,1),nanstd(tmp,0,1)/sqrt(size(tmp,1)),'k','linewidth',3);
    xlim([1-0.5 length(BIN)+0.5]);
    set(gca,'xtick',1:length(BIN),'xticklabel',num2str(BIN'),'fontname','helvetica','fontsize',14,'fontweight','normal')
    ylabel(MIForceLabels{mm},'fontname','helvetica','fontsize',16,'fontweight','bold');
    xlabel('\Deltat [ms]','fontname','helvetica','fontsize',16,'fontweight','bold');
%     ylabel('I [bit]');
    
    [p(2,mm),table,stats] = anova1(tmp,num2str(BIN'),'off');
    [c m h]=multcompare(stats,'display','off');
    cmpr{2,mm}=c(c(:,3)>0,1:2);
end;

set(hs(2,1),'ylim',[.25 .5]);
set(hs(2,2),'ylim',[.25 .5]);
set(hs(2,3),'ylim',[0 0.15]);

% display stat tests
clear txtdisp;
tt=1;
for pp=1:2
    txtdisp{tt}= [PerfLabels{pp} ': p = ' num2str(p(1,pp))]; tt=tt+1;
    txtdisp{tt}='';
    for rr=1:size(cmpr{1,pp},1), 
        txtdisp{tt}=[txtdisp{tt} num2str(BIN(cmpr{1,pp}(rr,1))) ' & ' num2str(BIN(cmpr{1,pp}(rr,2))) ', ']; 
        if rr==5 & size(cmpr{1,pp},1),
            tt=tt+1; txtdisp{tt}='';
        end;
    end;
    txtdisp{tt}(end-1:end)='';
    tt=tt+2;
end;

for mm=1:3
    txtdisp{tt}= [MIForceLabels{mm} ': p = ' num2str(p(2,mm))]; tt=tt+1;
    txtdisp{tt}='';
    for rr=1:size(cmpr{2,mm},1), 
        txtdisp{tt}=[txtdisp{tt} num2str(BIN(cmpr{2,mm}(rr,1))) ' & ' num2str(BIN(cmpr{2,mm}(rr,2))) ', ']; 
        if rr==5 & size(cmpr{2,mm},1)>5,
            tt=tt+1; txtdisp{tt}='';
        end;
    end;
    txtdisp{tt}(end-1:end)='';
    tt=tt+2;
end;

hb=annotation('textbox',[.65 .85 .1 .1]);
set(hb,'string',txtdisp,'fontsize',10)


if savefigs
    set(gcf,'color',[1 1 1])
    fname=['MICR_meanSEM_anova_' opts.algo '_' opts.dynSys '_' opts.sim '_' rmcond];
    dirs = dir_opts_REPOSITORY;
    export_fig(fullfile(dirs.plotPerfMI,[fname '.eps']));
    saveas(gcf,fullfile(dirs.plotPerfMI,fname),'fig');
    close;
end;

%%
% -------------------------
% plot boxplots
% -------------------------

figure
set(gcf, 'name', ['window: ' num2str(WINDOW) ' [ms]'],'pos',[73         159        1214         667]);

for pp=1:length(PerfLabels)
    hs(pp)=subplot(2,3,pp);
    boxplot(squeeze(PERF(:,:,pp)), BIN);
    xlabel('\Deltat [ms]');
    ylabel(PerfLabels{pp});
end;

set(hs(1),'ylim',[-50 100])
set(hs(2),'ylim',[-0.005 0.031])

for mm=1:length(MIFopt)
    subplot(2,3,3+mm)
    boxplot(squeeze(INFO(:,:,mm)), BIN);
    title(MIForceLabels{mm});
    xlabel('\Deltat [ms]');
    ylabel('I [bit]');
%     ylim([-.1 .6])
end;

if savefigs
    set(gcf,'color',[1 1 1])
    fname=['MICRboxplot_' opts.algo '_' opts.dynSys '_' opts.sim '_' rmcond];
    dirs = dir_opts_REPOSITORY;
    export_fig(fullfile(dirs.plotPerfMI,[fname '.eps']));
    saveas(gcf,fullfile(dirs.plotPerfMI,fname),'fig');
    close;
end;

%% -------------------------
% plot correlations
% -------------------------

figure;
set(gcf, 'name', ['window: ' num2str(WINDOW) ' [ms]']);

for ii = 1:size(PERF,3)
    for jj = 1:size(INFO,3)
        subplot(2,3,3*(ii-1)+jj)
        info = squeeze(INFO(:,:,jj));
        perf = squeeze(PERF(:,:,ii));
%         perf(find(isnan(info))) = 100;
%         info(find(isnan(info))) = 0;
        plot(info(:),perf(:),'.');
        xlabel(MIForceLabels{jj});
        ylabel(PerfLabels{ii});
        [h, p] = corrcoef(info(:),perf(:));
        title(cat(2,'r: ', num2str(h(2)), ' p: ', num2str(p(2))));
    end
end

